PROGRAM_NAME='Netlinx SR3 Demo'
(*{{PS_SOURCE_INFO(PROGRAM STATS)                          *)
(***********************************************************)
(*  FILE CREATED ON: 07/28/2001 AT: 16:01:59               *)
(***********************************************************)
(*  FILE_LAST_MODIFIED_ON: 10/30/2001 AT: 15:09:02         *)
(***********************************************************)
(*  ORPHAN_FILE_PLATFORM: 1                                *)
(***********************************************************)
(*!!FILE REVISION:                                         *)
(*  REVISION DATE: 10/03/2001                              *)
(*                                                         *)
(*  COMMENTS:                                              *)
(*                                                         *)
(***********************************************************)
(*}}PS_SOURCE_INFO                                         *)
(***********************************************************)

(***********************************************************)
(* System Type : Netlinx                                   *)
(***********************************************************)
(* REV HISTORY:                                            *)
(***********************************************************)
(* Although multiple SR3s can be connected, AMX may only   *)
(* be able to operate up to 3 SR3s at one time.            *)
(* Libary files: DoRw485.lib, DoSr3.Lib, RW485Vols.Lib     *)
(* AXI Files: RaneCon.axi, RaneVar.axi, RaneIni.axi,       *)
(*            RW_START.axi                                 *)
(* SR3 variables that you can work with:                   *)
(* SR3level[8], SR3page[8], SR3time[8], SR3cmd[8],         *)
(* SR3Lock[8], UpdateSR3[8], SR3mutes[8]                   *)
(* These variables are updated in DoSR3.lib.               *)
(* See RaneVar.axi for information on these Variables.     *)
(* Use string Variable RaneInfo for debugging              *)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
RW485       = 1:1:0      (* RANE RW485                     *)
TP          = 128:1:1    (* AXT-CA10/AXLINK                *)

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT
INCLUDE_RW485 = 1   (* This Program uses RW485 *)
INCLUDE_SR3   = 1   (* This Program uses the SR 3 *)

VOL_SPEED = 1  (* USED in RWvols to control the speed of the volume bar *)
INCLUDE 'RaneCon.axi'   (* Rane Constants - Contains all the SPLs *)

(* SR3active = 3  SR3 set to address 0 and 1 are used *)
(* Bitwise - SR3 set to address 0 = Bit 0, SR3 set to address 1 = Bit 1, *)
(* SR3 set to address 2 = Bit 2, SR3 set to address 3 = Bit 3,           *)
(* SR3 set to address 4 = Bit 4, SR3 set to address 5 = Bit 5...         *)
CONNECTED_SR3 = 2 // SR3 set to address 1

SR3_ADDR_0 = 0
SR3_ADDR_1 = 1
SR3_ADDR_2 = 2
SR3_ADDR_3 = 3
SR3_ADDR_4 = 4
SR3_ADDR_5 = 5
SR3_ADDR_6 = 6
SR3_ADDR_7 = 7

SR3_0_VOL_BAR = 1
SR3_1_VOL_BAR = 2
SR3_2_VOL_BAR = 3
SR3_3_VOL_BAR = 4
SR3_4_VOL_BAR = 5
SR3_5_VOL_BAR = 6
SR3_6_VOL_BAR = 7
SR3_7_VOL_BAR = 8

PAGE_1_BTN = 1
PAGE_2_BTN = 2
PAGE_3_BTN = 3
PAGE_4_BTN = 4
PAGE_5_BTN = 5
PAGE_6_BTN = 6
PAGE_7_BTN = 7
PAGE_8_BTN = 8
PAGE_9_BTN = 9
PAGE_10_BTN = 10
PAGE_11_BTN = 11
PAGE_12_BTN = 12
PAGE_13_BTN = 13
PAGE_14_BTN = 14
PAGE_15_BTN = 15
PAGE_16_BTN = 16

SR3_0_UP_BTN     = 17
SR3_0_DWN_BTN    = 18
SR3_0_MUTE_BTN   = 19

SR3_1_UP_BTN     = 21
SR3_1_DWN_BTN    = 22
SR3_1_MUTE_BTN   = 23
SR3_1_UNMUTE_BTN = 20

SR3_2_UP_BTN     = 24
SR3_2_DWN_BTN    = 25
SR3_2_MUTE_BTN   = 26
SR3_3_UP_BTN     = 27
SR3_3_DWN_BTN    = 28
SR3_3_MUTE_BTN   = 29
SR3_4_UP_BTN     = 30
SR3_4_DWN_BTN    = 31
SR3_4_MUTE_BTN   = 32
SR3_5_UP_BTN     = 33
SR3_5_DWN_BTN    = 34
SR3_5_MUTE_BTN   = 35
SR3_6_UP_BTN     = 36
SR3_6_DWN_BTN    = 37
SR3_6_MUTE_BTN   = 38
SR3_7_UP_BTN     = 39
SR3_7_DWN_BTN    = 40
SR3_7_MUTE_BTN   = 41

LOCK1_BTN = 51
LOCK2_BTN = 52

CONTROL_SR3_0_BTN = 60
CONTROL_SR3_1_BTN = 61
CONTROL_SR3_2_BTN = 62
CONTROL_SR3_3_BTN = 63
CONTROL_SR3_4_BTN = 64
CONTROL_SR3_5_BTN = 65
CONTROL_SR3_6_BTN = 66
CONTROL_SR3_7_BTN = 67

STRING_BTN = 68

SELECT_SR3_0_BTN = 70
SELECT_SR3_1_BTN = 71
SELECT_SR3_2_BTN = 72
SELECT_SR3_3_BTN = 73
SELECT_SR3_4_BTN = 74
SELECT_SR3_5_BTN = 75
SELECT_SR3_6_BTN = 76
SELECT_SR3_7_BTN = 77

SYSTEM_ON_BTN  = 100
SYSTEM_OFF_BTN = 101

KEY_FONT         = '3'  (* Medium Font *)

(***********************************************************)
(*              DATA TYPE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_TYPE

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

INCLUDE 'RaneVar.axi'  (* Rane Variables *)
SystemOn
OldSR3level[8]
Volume0
Volume1
Volume2
Volume3
Volume4
Volume5
Volume6
Volume7
OldVolume0
OldVolume1
OldVolume2
OldVolume3
OldVolume4
OldVolume5
OldVolume6
OldVolume7
NewVolume
SR3select
DisplayInfo

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE
([TP,SYSTEM_ON_BTN],[TP,SYSTEM_OFF_BTN])
([TP,PAGE_1_BTN]..[TP,PAGE_16_BTN])
([TP,CONTROL_SR3_0_BTN]..[TP,CONTROL_SR3_7_BTN])
(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
(* EXAMPLE: DEFINE_FUNCTION <RETURN_TYPE> <NAME> (<PARAMETERS>) *)
(* EXAMPLE: DEFINE_CALL '<NAME>' (<PARAMETERS>) *)


(* Initializes system by clearing or setting all startup parameters *)
DEFINE_FUNCTION INTEGER TestSR3 (INTEGER Addr,INTEGER Pup)
{
  SWITCH (Addr+1)
  {
    Case 1:
    {
      IF(SR3active & 1)
        RETURN 1
    }
    Case 2:
    {
      IF(SR3active & 2)
        RETURN 1
    }
    Case 3:
    {
      IF(SR3active & 4)
        RETURN 1
    }
    Case 4:
    {
      IF(SR3active & 8)
        RETURN 1
    }
    Case 5:
    {
      IF(SR3active & $10)
        RETURN 1
    }
    Case 6:
    {
      IF(SR3active & $20)
        RETURN 1
    }
    Case 7:
    {
      IF(SR3active & $40)
        RETURN 1
    }
    Case 8:
    {
      IF(SR3active & $80)
        RETURN 1
    }
  }
  IF (Pup)
    SEND_COMMAND TP,"'@PPN-NO SR3'"
  RETURN 0
}

DEFINE_CALL 'ClearSystem'
{
  OFF[TP,SR3_0_MUTE_BTN]
  OFF[TP,SR3_1_MUTE_BTN]
  ON[TP,SR3_1_UNMUTE_BTN]
  OFF[TP,SR3_2_MUTE_BTN]
  OFF[TP,SR3_3_MUTE_BTN]
  OFF[TP,SR3_4_MUTE_BTN]
  OFF[TP,SR3_5_MUTE_BTN]
  OFF[TP,SR3_6_MUTE_BTN]
  OFF[TP,SR3_7_MUTE_BTN]
  OFF[TP,LOCK1_BTN]
  OFF[TP,LOCK2_BTN]
  [TP,SELECT_SR3_0_BTN] = (SR3active & 1)
  [TP,SELECT_SR3_1_BTN] = (SR3active & 2)
  [TP,SELECT_SR3_2_BTN] = (SR3active & 4)
  [TP,SELECT_SR3_3_BTN] = (SR3active & 8)
  [TP,SELECT_SR3_4_BTN] = (SR3active & $10)
  [TP,SELECT_SR3_5_BTN] = (SR3active & $20)
  [TP,SELECT_SR3_6_BTN] = (SR3active & $40)
  [TP,SELECT_SR3_7_BTN] = (SR3active & $80)
  SYSTEM_CALL 'RaneIni'  (* Clear Rane Variables *)
  RaneInfo  = "" (* Use this variable for system debug *)
  SEND_COMMAND TP,"'!T',1,'|'"
}

(*********** System Start ****************)
(* Initializes system by clearing or setting all startup parameters,
   recalling memory 1 port and mic settings for ECB, memory 1 for the RPD 1, *)
DEFINE_CALL 'SystemStart'
{
  CHAR N

  SYSTEM_CALL 'RaneIni'  (* Clear Rane Variables *)
  N = 1
  // Set all startup levels and pages
  WHILE (N < 9)
  {
    SR3level[n] = 0  // level is offset by -1 so that SR3 @ 1 = 0; 31 = 30
    OldSR3level[n] = 0
    SR3page[n] = 1   // Forces page to 1
    N++
  }
  RaneInfo = "" (* Use this variable for system debug *)
  (* Reset RW485vols *)
  SYSTEM_CALL 'RW485Vols'(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 0)

  Volume0 = 128
  Volume1 = 128
  Volume2 = 128
  Volume3 = 128
  Volume4 = 128
  Volume5 = 128
  Volume6 = 128
  Volume7 = 128
  OldVolume0 = 0
  OldVolume1 = 0
  OldVolume2 = 0
  OldVolume3 = 0
  OldVolume4 = 0
  OldVolume5 = 0
  OldVolume6 = 0
  OldVolume7 = 0
  StopSR3 = 10  // Delay start of DoSR3

  ON [TP,SYSTEM_ON_BTN]
  SystemOn    = 1
  SystemReady = 1
  (* Bitwise - SR3 set to address 0 = Bit 0, SR3 set to address 1 = Bit 1, SR3 set to address 2 = Bit 2, *)
  (* SR3 set to address 3 = Bit 3, SR3 set to address 4 = Bit 4, SR3 set to address 5 = Bit 5... *)
  (* SR3active = 3  SR3 address 0 and 1 are used *)
  SR3select = 2 (* Start off with SR 3 address 1 *)
  ON[TP,SELECT_SR3_1_BTN]
  ON[TP,CONTROL_SR3_1_BTN]
  SEND_COMMAND TP,"'!F',2,KEY_FONT"
  SEND_COMMAND TP,"'!T',1,'|'"
  DisplayInfo = 1
}

(*********** System Off ****************)
DEFINE_CALL 'SystemOff'
{
  (* Power-Down system *)
  SR3active = CONNECTED_SR3 (* Only SR3 set to address 1 is used at startup *)
  (* Bitwise - SR3 set to address 0 = Bit 0, SR3 set to address 1 = Bit 1, SR3 set to address 2 = Bit 2, *)
  (* SR3 set to address 3 = Bit 3, SR3 set to address 4 = Bit 4, SR3 set to address 5 = Bit 5... *)
  (* SR3active = 3  SR3 address 0 and 1 are used *)
  SR3select = 2 (* Start off with SR 3 address 1 *)

  ON [TP,SYSTEM_OFF_BTN]
  SystemOn = 0
  SEND_COMMAND TP,"'@PPA'"  (* Clear all Popups *)
  WAIT 10 (* Use delay to clear errors in system *)
    CALL 'ClearSystem'
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START
(* RANE *)
CREATE_BUFFER RW485, RW485rxBuffer

CALL 'SystemOff'
SEND_COMMAND TP,"'WAKE'"
SEND_COMMAND TP,"'PAGE-Main Page'"

(***********************************************************)
(*                THE EVENTS GOES BELOW                    *)
(***********************************************************)
DEFINE_EVENT

DATA_EVENT[RW485] // RW485 setup
{
  ONLINE:
  {
    SEND_COMMAND RW485, 'SET BAUD 38400,N,8,1,485 ENABLE'  // Direct connect
    SEND_COMMAND RW485,'HSOFF'
//    SEND_COMMAND RW485, 'SET BAUD 38400,N,8,1,485 DISABLE'  //Use with DSC 1 or 2
//    SEND_COMMAND RW485,'HSOFF'
  }
}

BUTTON_EVENT[TP,SYSTEM_ON_BTN]
{
  PUSH:
  {
    CALL 'SystemStart'
  }
}

BUTTON_EVENT[TP,SYSTEM_OFF_BTN]
{
  PUSH:
  {
    CALL 'SystemOff'
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_0_BTN]
{
  PUSH:
  {             // Address, 1=Pop Up on
    IF (TestSR3 (SR3_ADDR_0,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_0_BTN]
      SR3select = 1
      NewSR3page[SR3select] = 1  // Force page display
      SEND_COMMAND TP,"'PAGE-SR3-0'"
    }
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_1_BTN]
{
  PUSH:
  {
    IF (TestSR3 (SR3_ADDR_1,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_1_BTN]
      SR3select = 2
      NewSR3page[SR3select] = 1
      SEND_COMMAND TP,"'PAGE-SR3-1'"
    }
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_2_BTN]
{
  PUSH:
  {
    IF (TestSR3 (SR3_ADDR_2,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_2_BTN]
      SR3select = 3
      NewSR3page[SR3select] = 1
      SEND_COMMAND TP,"'PAGE-SR3-2'"
    }
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_3_BTN]
{
  PUSH:
  {
    IF (TestSR3 (SR3_ADDR_3,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_3_BTN]
      SR3select = 4
      NewSR3page[SR3select] = 1
      SEND_COMMAND TP,"'PAGE-SR3-3'"
    }
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_4_BTN]
{
  PUSH:
  {
    IF (TestSR3 (SR3_ADDR_4,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_4_BTN]
      SR3select = 5
      NewSR3page[SR3select] = 1
      SEND_COMMAND TP,"'PAGE-SR3-4'"
    }
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_5_BTN]
{
  PUSH:
  {
    IF (TestSR3 (SR3_ADDR_5,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_5_BTN]
      SR3select = 6
      NewSR3page[SR3select] = 1
      SEND_COMMAND TP,"'PAGE-SR3-5'"
    }
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_6_BTN]
{
  PUSH:
  {
    IF (TestSR3 (SR3_ADDR_6,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_6_BTN]
      SR3select = 7
      NewSR3page[SR3select] = 1
      SEND_COMMAND TP,"'PAGE-SR3-6'"
    }
  }
}

BUTTON_EVENT[TP,CONTROL_SR3_7_BTN]
{
  PUSH:
  {
    IF (TestSR3 (SR3_ADDR_7,1)) // Check to see if SR3 is connected
    {
      ON[TP,CONTROL_SR3_7_BTN]
      SR3select = 8
      NewSR3page[SR3select] = 1
      SEND_COMMAND TP,"'PAGE-SR3-7'"
    }
  }
}

BUTTON_EVENT[TP,SELECT_SR3_0_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_0_BTN] = ![TP,SELECT_SR3_0_BTN]
    IF ([TP,SELECT_SR3_0_BTN])
      SR3active =  SR3active | 1
    ELSE
      SR3active =  SR3active & ~1
  }
}

BUTTON_EVENT[TP,SELECT_SR3_1_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_1_BTN] = ![TP,SELECT_SR3_1_BTN]
    IF ([TP,SELECT_SR3_1_BTN])
      SR3active =  SR3active | 2
    ELSE
      SR3active =  SR3active & ~2
  }
}

BUTTON_EVENT[TP,SELECT_SR3_2_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_2_BTN] = ![TP,SELECT_SR3_2_BTN]
    IF ([TP,SELECT_SR3_2_BTN])
      SR3active =  SR3active | 4
    ELSE
      SR3active =  SR3active & ~4
  }
}

BUTTON_EVENT[TP,SELECT_SR3_3_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_3_BTN] = ![TP,SELECT_SR3_3_BTN]
    IF ([TP,SELECT_SR3_3_BTN])
      SR3active =  SR3active | 8
    ELSE
      SR3active =  SR3active & ~8
  }
}

BUTTON_EVENT[TP,SELECT_SR3_4_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_4_BTN] = ![TP,SELECT_SR3_4_BTN]
    IF ([TP,SELECT_SR3_4_BTN])
      SR3active =  SR3active | $10
    ELSE
      SR3active =  SR3active & ~$10
  }
}

BUTTON_EVENT[TP,SELECT_SR3_5_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_5_BTN] = ![TP,SELECT_SR3_5_BTN]
    IF ([TP,SELECT_SR3_5_BTN])
      SR3active =  SR3active | $20
    ELSE
      SR3active =  SR3active & ~$20
  }
}

BUTTON_EVENT[TP,SELECT_SR3_6_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_6_BTN] = ![TP,SELECT_SR3_6_BTN]
    IF ([TP,SELECT_SR3_6_BTN])
      SR3active =  SR3active | $40
    ELSE
      SR3active =  SR3active & ~$40
  }
}

BUTTON_EVENT[TP,SELECT_SR3_7_BTN]
{
  PUSH:
  {
    [TP,SELECT_SR3_7_BTN] = ![TP,SELECT_SR3_7_BTN]
    IF ([TP,SELECT_SR3_7_BTN])
      SR3active =  SR3active | $80
    ELSE
      SR3active =  SR3active & ~$80
  }
}

BUTTON_EVENT[TP,PAGE_1_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_1_BTN]
      SR3page[SR3select] = 1
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','1')
    }
  }
}

BUTTON_EVENT[TP,PAGE_2_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_2_BTN]
      SR3page[SR3select] = 2
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','2')
    }
  }
}

BUTTON_EVENT[TP,PAGE_3_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_3_BTN]
      SR3page[SR3select] = 3
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','3')
    }
  }
}

BUTTON_EVENT[TP,PAGE_4_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_4_BTN]
      SR3page[SR3select] = 4
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','4')
    }
  }
}

BUTTON_EVENT[TP,PAGE_5_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_5_BTN]
      SR3page[SR3select] = 5
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','5')
    }
  }
}

BUTTON_EVENT[TP,PAGE_6_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_6_BTN]
      SR3page[SR3select] = 6
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','6')
    }
  }
}

BUTTON_EVENT[TP,PAGE_7_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_7_BTN]
      SR3page[SR3select] = 7
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','7')
    }
  }
}

BUTTON_EVENT[TP,PAGE_8_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_8_BTN]
      SR3page[SR3select] = 8
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','8')
    }
  }
}

BUTTON_EVENT[TP,PAGE_9_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_9_BTN]
      SR3page[SR3select] = 9
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','9')
    }
  }
}

BUTTON_EVENT[TP,PAGE_10_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_10_BTN]
      SR3page[SR3select] = 10
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','10')
    }
  }
}

BUTTON_EVENT[TP,PAGE_11_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_11_BTN]
      SR3page[SR3select] = 11
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','11')
    }
  }
}

BUTTON_EVENT[TP,PAGE_12_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_12_BTN]
      SR3page[SR3select] = 12
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','12')
    }
  }
}

BUTTON_EVENT[TP,PAGE_13_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_13_BTN]
      SR3page[SR3select] = 13
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','13')
    }
  }
}

BUTTON_EVENT[TP,PAGE_14_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_14_BTN]
      SR3page[SR3select] = 14
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','14')
    }
  }
}

BUTTON_EVENT[TP,PAGE_15_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_15_BTN]
      SR3page[SR3select] = 15
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','15')
    }
  }
}

BUTTON_EVENT[TP,PAGE_16_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      ON[TP,PAGE_16_BTN]
      SR3page[SR3select] = 16
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'PS','16')
    }
  }
}

BUTTON_EVENT[TP,STRING_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      TO[TP,STRING_BTN]
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'FNT','1')
  //    SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'MC','0,0')
  //    SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'STR','"Hello From Rane"') // Must have " " around string
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'SC','2,"Hello"') // String Center Must have " " around string
      SYSTEM_CALL 'RW485_Q' (SR3select-1,SR_3,'SC','0,"From Rane"') // Must have " " around string
    }
  }
}

BUTTON_EVENT[TP,LOCK1_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      [TP,LOCK1_BTN] = ![TP,LOCK1_BTN]
      SR3lock[2] = [TP,LOCK1_BTN]
      IF ([TP,LOCK1_BTN])
        SYSTEM_CALL 'RW485_Q' (SR3_ADDR_1,SR_3,'ILK','7') (* Lock All *)
      ELSE
      {
        IF (SR3mutes[2])
          SYSTEM_CALL 'RW485_Q' (SR3_ADDR_1,SR_3,'ILK','1') (* Lock Encoder *)
        ELSE  
          SYSTEM_CALL 'RW485_Q' (SR3_ADDR_1,SR_3,'ILK','0') (* UnLock All *)
      }
    }
  }
}
  
BUTTON_EVENT[TP,LOCK2_BTN]
{
  PUSH:
  {
    IF (SystemOn && SystemReady)
    {
      [TP,LOCK2_BTN] = ![TP,LOCK2_BTN]
      SR3lock[3] = [TP,LOCK2_BTN]
      IF ([TP,LOCK2_BTN])
        SYSTEM_CALL 'RW485_Q' (SR3_ADDR_2,SR_3,'ILK','7') (* Lock All *)
      ELSE
      {
        IF (SR3mutes[3])
          SYSTEM_CALL 'RW485_Q' (SR3_ADDR_2,SR_3,'ILK','1') (* Lock Encoder *)
        ELSE  
          SYSTEM_CALL 'RW485_Q' (SR3_ADDR_2,SR_3,'ILK','0') (* UnLock All *)
      }
    }
  }
}

LEVEL_EVENT[TP,SR3_0_VOL_BAR]
{
  Volume0 = LEVEL.VALUE
}

LEVEL_EVENT[TP,SR3_1_VOL_BAR]
{
  Volume1 = LEVEL.VALUE
}

LEVEL_EVENT[TP,SR3_2_VOL_BAR]
{
  Volume2 = LEVEL.VALUE
}

LEVEL_EVENT[TP,SR3_3_VOL_BAR]
{
  Volume3 = LEVEL.VALUE
}

LEVEL_EVENT[TP,SR3_4_VOL_BAR]
{
  Volume4 = LEVEL.VALUE
}

LEVEL_EVENT[TP,SR3_5_VOL_BAR]
{
  Volume5 = LEVEL.VALUE
}

LEVEL_EVENT[TP,SR3_6_VOL_BAR]
{
  Volume6 = LEVEL.VALUE
}

LEVEL_EVENT[TP,SR3_7_VOL_BAR]
{
  Volume7 = LEVEL.VALUE
}

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

IF (BadRaneData && DisplayInfo)
{
  SEND_COMMAND TP,"'!T',1,RaneInfo"
  DisplayInfo = 0
  WAIT 50
    SEND_COMMAND TP,"'!T',1,'Restart System'"

}

(* CONTROL FOR RANE ECB 62 BASE *)
IF (SystemOn && SystemReady)
{

  IF (TestSR3 (SR3_ADDR_0,0)) // Check to see if SR3 is connected
  {
 (* Level Format *)   (* TP, Up Btn, Dwn Btn, Mute Btn, UnMute Btn, Device Type,
                         Device Address, Level, OldLevel, SR3level, OldSR3Level, NewVolume, Force Update *)
                      (*  Set UnMute to 0 to use Mute as Toggle *)
(****** SR3 Level Control *********)
    NewVolume = 1  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_0_UP_BTN, SR3_0_DWN_BTN, SR3_0_MUTE_BTN, 0, SR_3,
                            SR3_ADDR_0, Volume0, OldVolume0, SR3level[1], OldSR3level[1], NewVolume, 0)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_0_VOL_BAR,Volume0
  }

  IF (TestSR3 (SR3_ADDR_1,0)) // Check to see if SR3 is connected
  {
    NewVolume = 2  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
//Notes:
(* Force Update does a quick update of the volume control, but stops all other updates from the SR3s
   by setting StopSR3 during level change. *)
(* SR3 address 1 uses both the Mute and UnMute buttons *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_1_UP_BTN, SR3_1_DWN_BTN, SR3_1_MUTE_BTN, SR3_1_UNMUTE_BTN, SR_3,
                            SR3_ADDR_1, Volume1, OldVolume1, SR3level[2], OldSR3level[2], NewVolume, 1)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_1_VOL_BAR,Volume1
  }

  IF (TestSR3 (SR3_ADDR_2,0)) // Check to see if SR3 is connected
  {
    NewVolume = 3  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_2_UP_BTN, SR3_2_DWN_BTN, SR3_2_MUTE_BTN, 0, SR_3,
                            SR3_ADDR_2, Volume2, OldVolume2, SR3level[3], OldSR3level[3], NewVolume, 0)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_2_VOL_BAR,Volume2
  }

  IF (TestSR3 (SR3_ADDR_3,0)) // Check to see if SR3 is connected
  {
    NewVolume = 4  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_3_UP_BTN, SR3_3_DWN_BTN, SR3_3_MUTE_BTN, 0, SR_3,
                            SR3_ADDR_3, Volume3, OldVolume3, SR3level[4], OldSR3level[4], NewVolume, 0)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_3_VOL_BAR,Volume3
  }

  IF (TestSR3 (SR3_ADDR_4,0)) // Check to see if SR3 is connected
  {
    NewVolume = 5  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_4_UP_BTN, SR3_4_DWN_BTN, SR3_4_MUTE_BTN, 0, SR_3,
                            SR3_ADDR_4, Volume4, OldVolume4, SR3level[5], OldSR3level[5], NewVolume, 0)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_4_VOL_BAR,Volume4
  }

  IF (TestSR3 (SR3_ADDR_5,0)) // Check to see if SR3 is connected
  {
    NewVolume = 6  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_5_UP_BTN, SR3_5_DWN_BTN, SR3_5_MUTE_BTN, 0, SR_3,
                            SR3_ADDR_5, Volume5, OldVolume5, SR3level[6], OldSR3level[6], NewVolume, 0)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_5_VOL_BAR,Volume5
  }

  IF (TestSR3 (SR3_ADDR_6,0)) // Check to see if SR3 is connected
  {
    NewVolume = 7  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_6_UP_BTN, SR3_6_DWN_BTN, SR3_6_MUTE_BTN, 0, SR_3,
                            SR3_ADDR_6, Volume6, OldVolume6, SR3level[7], OldSR3level[7], NewVolume, 0)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_6_VOL_BAR,Volume6
  }

  IF (TestSR3 (SR3_ADDR_7,0)) // Check to see if SR3 is connected
  {
    NewVolume = 1  (* Use NewVolume for the Volume # - Each NewVolume must have a different number *)
                   (* If the level changes NewVolume = 1 *)
    SYSTEM_CALL 'RW485Vols'(TP, SR3_7_UP_BTN, SR3_7_DWN_BTN, SR3_7_MUTE_BTN, 0, SR_3,
                            SR3_ADDR_7, Volume7, OldVolume7, SR3level[8], OldSR3level[8], NewVolume, 0)
    IF (NewVolume)
      SEND_LEVEL TP,SR3_7_VOL_BAR,Volume7
  }

// Display the selected page
  IF (NewSR3page[SR3select])
  {
    NewSR3page[SR3select] = 0
    SWITCH (SR3page[SR3select])
    {
      CASE 1:
      {
        ON[TP,PAGE_1_BTN]
      }
      CASE 2:
      {
        ON[TP,PAGE_2_BTN]
      }
      CASE 3:
      {
        ON[TP,PAGE_3_BTN]
      }
      CASE 4:
      {
        ON[TP,PAGE_4_BTN]
      }
      CASE 5:
      {
        ON[TP,PAGE_5_BTN]
      }
      CASE 6:
      {
        ON[TP,PAGE_6_BTN]
      }
      CASE 7:
      {
        ON[TP,PAGE_7_BTN]
      }
      CASE 8:
      {
        ON[TP,PAGE_8_BTN]
      }
      CASE 9:
      {
        ON[TP,PAGE_9_BTN]
      }
      CASE 10:
      {
        ON[TP,PAGE_10_BTN]
      }
      CASE 11:
      {
        ON[TP,PAGE_11_BTN]
      }
      CASE 12:
      {
        ON[TP,PAGE_12_BTN]
      }
      CASE 13:
      {
        ON[TP,PAGE_13_BTN]
      }
      CASE 14:
      {
        ON[TP,PAGE_14_BTN]
      }
      CASE 15:
      {
        ON[TP,PAGE_15_BTN]
      }
      CASE 16:
      {
        ON[TP,PAGE_16_BTN]
      }
    }
  }
}

IF (SystemOn)
{
  SYSTEM_CALL 'DoSR3'    // Place above DoRW485 - check SR3 for its data
  SYSTEM_CALL 'DoRW485' (RW485) // check RW485_Q and empty
}
(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

