PROGRAM_NAME='RwDemo1 - RaneWare DEMO 1 With SR 1Ls'
(*   DATE:10/10/01    TIME:16:01:49    *)
(* Rane Corp. By: Mike Slattery                                          *)
(* This program demonstrates the ability of Panja to control the         *)
(* ECB 62, ECM 64, RPD 1, RPE 228, and the RPM 26v. The program          *)
(* also uses two SR lLs to control the volume levels of the ECB 62 and   *)
(* RPE 228d/RPM 26v. Opstat messages from the ECB 62e are retrieved to   *)
(* determine the Master Mic and Master Port on ECS for                   *)
(* Video-Follows-Audio. Opstat messages from the ECM 64e are retrieved   *)
(* to determine if there is an incoming call. Using the RaneWare program *)
(* load the following:                                                   *)
(* AMXD1.ECS file into the ECB 62e.                                      *)
(* AMXD1.RPD file into the RPD 1.                                        *)
(* AMXD1.C64 file into the ECM 64.                                       *)
(* Set the RW232 Address as follows:                                     *)
(* RPD 1    to 1                                                         *)
(* RPE 228d to 2                                                         *)
(* RPM 26v  to 3                                                         *)
(* ECB 62   to 4                                                         *)
(* ECM 64   to 5                                                         *)
(*                                                                       *)
(* Load the touch panel file RwDemo1.PGC                                 *)
(* Include files: RaneCon.axi, RaneVar.axi                               *)
(* Library Files: RW232_Q.lib, DoRW232.lib, RaneIni.lib, Rw232Vols.lib   *)
(*                SR1_Q.lib, DoSR1.lib                                   *)
(*************************************************************************)

(*!!!!!!!!!!! Variable RaneInfo can be used for diagnostics !!!!!!!!!!!!!*)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
RW232       = 1  (* AXC-SER RANE RW232 *)
                 (* BAUD 19200,E,8,1 485 DISABLED *)
SR1         = 2  (* AXC-SER RANE SR1 *)
                 (* BAUD 9600,N,8,1,485 ENABLE *)
TP          = 128

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(* Opstats are used for video-follows-audio apps and Hybrid status *)

(* !!!!! Don't include (INCLUDE_<UNIT>) if not used -
         Comment out or remove (INCLUDE_<UNIT>) !!!!! *)

INCLUDE_RW232         = 1   (* This Program uses RW232       *)
INCLUDE_ECB62         = 1   (* This Program uses the ECB 62e *)
INCLUDE_RPD1          = 1   (* This Program uses an RPD 1    *)
INCLUDE_RPM26         = 1   (* This Program uses an RPM 26V  *)
INCLUDE_RPE228        = 1   (* This Program uses an RPE 228d *)
INCLUDE_ECM64         = 1   (* This Program uses the ECM 64e *)
INCLUDE_SR1           = 1   (* This Program uses SR 1Ls      *)
INCLUDE_OPSTATS       = 1   (* This Program uses Opstats     *)
INCLUDE_ECB62_OPSTATS = 1   (* This Program uses ECB OPSTATS *)
INCLUDE_ECM64_OPSTATS = 1   (* This Program uses ECM OPSTATS *)
  (* Must be after the Includes *)
INCLUDE 'RaneCon.axi'   (* RW232 Constants - Contains all the SPLs  *)

(* RW 232 Device Addresses *)
RPD1_ADDRESS   = 1
RPE228_ADDRESS = 2
RPM26_ADDRESS  = 3
ECB62_ADDRESS  = 4
ECM64_ADDRESS  = 5

(******** Button Names ***********)
PGM_VOL_BAR  = 1
RPM_VOL_BAR  = 2
ECM_VOL_BAR  = 3
MIC1_BTN    = 1
MIC2_BTN    = 2
MIC3_BTN    = 3
MIC4_BTN    = 4
MIC5_BTN    = 5
MIC6_BTN    = 6
MIC7_BTN    = 7
MIC8_BTN    = 8
PGM_UP_BTN  = 9
PGM_DWN_BTN = 10
MIXER1_BTN  = 11
MIXER2_BTN  = 12
MIXER3_BTN  = 13
MIXER4_BTN  = 14
MIXER5_BTN  = 15
MIXER6_BTN  = 16

MASTER_MIC1 = 17
MASTER_MIC2 = 18
MASTER_MIC3 = 19
MASTER_MIC4 = 20
MASTER_MIC5 = 21
MASTER_MIC6 = 22
MASTER_MIC7 = 23
MASTER_MIC8 = 24

AUTO_ANSWER_BTN  = 25
REMOTE_DIAG_BTN  = 26
PHONE_REDIAL_BTN = 27
CLEAR_BTN        = 28
HANG_UP_BTN      = 29

PORT1_IN_BTN    = 30
PORT2_IN_BTN    = 31
PORT3_IN_BTN    = 32
PORT4_IN_BTN    = 33
PORT5_IN_BTN    = 34
PORT6_IN_BTN    = 35
PORT1_OUT_BTN   = 36
PORT2_OUT_BTN   = 37
PORT3_OUT_BTN   = 38
PORT4_OUT_BTN   = 39
PORT5_OUT_BTN   = 40
PORT6_OUT_BTN   = 41

LOCATION1_BTN    = 42
LOCATION2_BTN    = 43
LOCATION3_BTN    = 44
LOCATION4_BTN    = 45
ANSWER_DIAL_BTN  = 46
PAUSE_FLASH_BTN  = 47
(* 48-59 Keypad *)
SELECT_ROUTE_BTN = 60
BACKSPACE_BTN    = 61
MASTER_PORT1     = 62
MASTER_PORT2     = 63
MASTER_PORT3     = 64
MASTER_PORT4     = 65
MASTER_PORT5     = 66
MASTER_PORT6     = 67
RING_LED         = 68
OFF_HOOK         = 69
MASTER_MIC_OFF   = 70
ECM_UP_BTN       = 71
ECM_DWN_BTN      = 72
RPM_UP_BTN       = 73
RPM_DWN_BTN      = 74
MEM1_BTN         = 75
MEM2_BTN         = 76
MEM3_BTN         = 77
MEM4_BTN         = 78

FORCE_MIC1_BTN = 80
FORCE_MIC2_BTN = 81
FORCE_MIC3_BTN = 82
FORCE_MIC4_BTN = 83
FORCE_MIC5_BTN = 84
FORCE_MIC6_BTN = 85
FORCE_MIC7_BTN = 86
FORCE_MIC8_BTN = 87

STORE_NUMBER_BTN    = 89
RPM_SELECT_BTN      = 90
RPE_SELECT_BTN      = 91
AUTO_DISCONNECT_BTN = 92

SYSTEM_ON_BTN      = 100
SYSTEM_OFF_BTN     = 101
VOLUME_BAR_BTNS    = 102
(************* END Button Names **************)

KEY_FONT         = '3'  (* Medium Font *)

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

INCLUDE 'RaneVar.axi'  (* RW232 Variables *)

KeyPadEntry[20]
LastEntry[20]
SingleKey[20]
Location1Text[20]
Location2Text[20]
Location3Text[20]
Location4Text[20]
TPbuf[10]
ButtonPushed
RW232data
Input1
Input2
Input3
Input4
Input5
Input6
Output1
Output2
Output3
Output4
Output5
Output6
SetButtons
Port1Inputs
Port2Inputs
Port3Inputs
Port4Inputs
Port5Inputs
Port6Inputs
LastButton
KeyPressed
Element
Selement
NewKey
ProgramLocation
KeyReady
Mixer1Mics
Mixer2Mics
Mixer3Mics
Mixer4Mics
Mixer5Mics
Mixer6Mics

MasterMicLed
VUmeter
MasterPort
MasterMic
OffHook

PGMVolume
OldPGMvolume
OldCPGMvol

ECMvolume
OldECMvolume
OldCECMvol

RPMvolume
RPEvolume
RPM_RPE_Volume
Old_RPM_RPE_Volume
Old_RPM_RPE_Cvolume
OldRPMvolume
OldRPEvolume
OldCRPMvol
OldCRPEvol

RPMmemory
RPEmemory

NewVolume
StopOpstat
SystemOn
MixOffset
DTMFrxNumber
ClearOldNumber

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       TOGGLING DEFINITIONS GO BELOW                     *)
(***********************************************************)
DEFINE_TOGGLING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE
([TP,MASTER_PORT1]..[TP,MASTER_PORT6])
([TP,MASTER_MIC1]..[TP,MASTER_MIC8],[TP,MASTER_MIC_OFF])
([TP,MIXER1_BTN]..[TP,MIXER6_BTN])
([TP,RPM_SELECT_BTN]..[TP,RPE_SELECT_BTN])
([TP,MEM1_BTN]..[TP,MEM4_BTN])
([TP,LOCATION1_BTN]..[TP,LOCATION4_BTN],[TP,CLEAR_BTN])
([TP,SYSTEM_ON_BTN],[TP,SYSTEM_OFF_BTN])

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)


(***************** Clear Inputs ****************)
DEFINE_CALL 'ClearInputs'
{
  OFF[TP,PORT1_IN_BTN]
  OFF[TP,PORT2_IN_BTN]
  OFF[TP,PORT3_IN_BTN]
  OFF[TP,PORT4_IN_BTN]
  OFF[TP,PORT5_IN_BTN]
  OFF[TP,PORT6_IN_BTN]
}

(***************** Reset Last ****************)

DEFINE_CALL 'ResetLast'
{
  IF (LastButton)
  {
    SELECT
    {
      ACTIVE (LastButton = PORT1_IN_BTN) : SEND_COMMAND TP,'ICON30-3'
      ACTIVE (LastButton = PORT2_IN_BTN) : SEND_COMMAND TP,'ICON31-3'
      ACTIVE (LastButton = PORT3_IN_BTN) : SEND_COMMAND TP,'ICON32-3'
      ACTIVE (LastButton = PORT4_IN_BTN) : SEND_COMMAND TP,'ICON33-3'
      ACTIVE (LastButton = PORT5_IN_BTN) : SEND_COMMAND TP,'ICON34-3'
      ACTIVE (LastButton = PORT6_IN_BTN) : SEND_COMMAND TP,'ICON35-3'
    }
  LastButton = 0
  }
}

(***************** Clear SingleKey ****************)
DEFINE_CALL 'ClearSingleKey'
{
  KeyReady = 0
  Selement = 0
  SET_LENGTH_STRING (SingleKey,0)
  SEND_COMMAND TP,'TEXT2-|'
}

(***************** Clear Key ****************)
DEFINE_CALL 'ClearKey'
{
  ON [TP,CLEAR_BTN]
  KeyReady = 0
  ProgramLocation = 0
  Element = 0
  SET_LENGTH_STRING (KeyPadEntry,0)
  OFF [TP,STORE_NUMBER_BTN]
  SEND_COMMAND TP,'TEXT2-|'
  ClearOldNumber = 0
}

(***************** Set Mics ********************)
(* This subroutine preforms the bitwize        *)
(* operation for each Mixer's mics.            *)
(***********************************************)
DEFINE_CALL 'SetMic' (MicOn,Mic,Mixer)
{
  SELECT
  {
    ACTIVE (Mixer = 0) :
    {
      SELECT
      {
        ACTIVE (Mic = 1) :
        {
          IF (MicOn)
            Mixer1Mics = Mixer1Mics | 1
          Else
            Mixer1Mics = Mixer1Mics & ~1
        }
        ACTIVE (Mic = 2) :
        {
          IF (MicOn)
            Mixer1Mics = Mixer1Mics | 2
          Else
            Mixer1Mics = Mixer1Mics & ~2
        }
        ACTIVE (Mic = 3) :
        {
          IF (MicOn)
            Mixer1Mics = Mixer1Mics | 4
          Else
            Mixer1Mics = Mixer1Mics & ~4
        }
        ACTIVE (Mic = 4) :
        {
          IF (MicOn)
            Mixer1Mics = Mixer1Mics | 8
          Else
            Mixer1Mics = Mixer1Mics & ~8
        }
        ACTIVE (Mic = 5) :
        {
          IF (MicOn)
            Mixer1Mics = Mixer1Mics | 16
          Else
            Mixer1Mics = Mixer1Mics & ~16
        }
        ACTIVE (Mic = 6) :
        {
          IF (MicOn)
            Mixer1Mics = Mixer1Mics | 32
          Else
            Mixer1Mics = Mixer1Mics & ~32
        }
        ACTIVE (Mic = 7) :
        {
          IF (MicOn)
            Mixer1Mics = Mixer1Mics | 64
          Else
            Mixer1Mics = Mixer1Mics & ~64
        }
        ACTIVE (Mic = 8) :
        {
          IF (MicOn)
             Mixer1Mics = Mixer1Mics | 128
          Else
            Mixer1Mics = Mixer1Mics & ~128
        }
      }
    }
    ACTIVE (Mixer = ECB62_MIX_OFFSET) :    (* Mixer 2 *)
    {
      SELECT
      {
        ACTIVE (Mic = 1) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 1
          Else
            Mixer2Mics = Mixer2Mics & ~1
        }
        ACTIVE (Mic = 2) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 2
          Else
            Mixer2Mics = Mixer2Mics & ~2
        }
        ACTIVE (Mic = 3) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 4
          Else
            Mixer2Mics = Mixer2Mics & ~4
         }
        ACTIVE (Mic = 4) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 8
          Else
            Mixer2Mics = Mixer2Mics & ~8
        }
        ACTIVE (Mic = 5) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 16
          Else
            Mixer2Mics = Mixer2Mics & ~16
        }
        ACTIVE (Mic = 6) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 32
          Else
            Mixer2Mics = Mixer2Mics & ~32
        }
        ACTIVE (Mic = 7) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 64
          Else
            Mixer2Mics = Mixer2Mics & ~64
        }
        ACTIVE (Mic = 8) :
        {
          IF (MicOn)
            Mixer2Mics = Mixer2Mics | 128
          Else
            Mixer2Mics = Mixer2Mics & ~128
        }
      }
    }
    ACTIVE (Mixer = ECB62_MIX_OFFSET * 2) :   (* Mixer 3 *)
    {
      SELECT
      {
        ACTIVE (Mic = 1) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 1
          Else
            Mixer3Mics = Mixer3Mics & ~1
        }
        ACTIVE (Mic = 2) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 2
          Else
            Mixer3Mics = Mixer3Mics & ~2
        }
        ACTIVE (Mic = 3) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 4
          Else
            Mixer3Mics = Mixer3Mics & ~4
        }
        ACTIVE (Mic = 4) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 8
          Else
            Mixer3Mics = Mixer3Mics & ~8
        }
        ACTIVE (Mic = 5) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 16
          Else
            Mixer3Mics = Mixer3Mics & ~16
         }
        ACTIVE (Mic = 6) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 32
          Else
            Mixer3Mics = Mixer3Mics & ~32
        }
        ACTIVE (Mic = 7) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 64
          Else
            Mixer3Mics = Mixer3Mics & ~64
        }
        ACTIVE (Mic = 8) :
        {
          IF (MicOn)
            Mixer3Mics = Mixer3Mics | 128
          Else
            Mixer3Mics = Mixer3Mics & ~128
        }
      }
    }
    ACTIVE (Mixer = ECB62_MIX_OFFSET * 3) :    (* Mixer 4 *)
    {
      SELECT
      {
        ACTIVE (Mic = 1) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 1
          Else
            Mixer4Mics = Mixer4Mics & ~1
        }
        ACTIVE (Mic = 2) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 2
          Else
            Mixer4Mics = Mixer4Mics & ~2
        }
        ACTIVE (Mic = 3) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 4
          Else
            Mixer4Mics = Mixer4Mics & ~4
        }
        ACTIVE (Mic = 4) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 8
          Else
            Mixer4Mics = Mixer4Mics & ~8
        }
        ACTIVE (Mic = 5) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 16
          Else
            Mixer4Mics = Mixer4Mics & ~16
        }
        ACTIVE (Mic = 6) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 32
          Else
            Mixer4Mics = Mixer4Mics & ~32
        }
        ACTIVE (Mic = 7) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 64
          Else
            Mixer4Mics = Mixer4Mics & ~64
        }
        ACTIVE (Mic = 8) :
        {
          IF (MicOn)
            Mixer4Mics = Mixer4Mics | 128
          Else
            Mixer4Mics = Mixer4Mics & ~128
        }
      }
    }
    ACTIVE (Mixer = ECB62_MIX_OFFSET * 4) :    (* Mixer 5 *)
    {
      SELECT
      {
        ACTIVE (Mic = 1) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 1
          Else
            Mixer5Mics = Mixer5Mics & ~1
        }
        ACTIVE (Mic = 2) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 2
          Else
            Mixer5Mics = Mixer5Mics & ~2
        }
        ACTIVE (Mic = 3) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 4
          Else
            Mixer5Mics = Mixer5Mics & ~4
        }
        ACTIVE (Mic = 4) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 8
          Else
            Mixer5Mics = Mixer5Mics & ~8
        }
        ACTIVE (Mic = 5) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 16
          Else
            Mixer5Mics = Mixer5Mics & ~16
        }
        ACTIVE (Mic = 6) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 32
          Else
            Mixer5Mics = Mixer5Mics & ~32
        }
        ACTIVE (Mic = 7) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 64
          Else
            Mixer5Mics = Mixer5Mics & ~64
        }
        ACTIVE (Mic = 8) :
        {
          IF (MicOn)
            Mixer5Mics = Mixer5Mics | 128
          Else
            Mixer5Mics = Mixer5Mics & ~128
        }
      }
    }
    ACTIVE (Mixer = ECB62_MIX_OFFSET * 5) :    (* Mixer 6 *)
    {
      SELECT
      {
        ACTIVE (Mic = 1) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 1
          Else
            Mixer6Mics = Mixer6Mics & ~1
        }
        ACTIVE (Mic = 2) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 2
          Else
            Mixer6Mics = Mixer6Mics & ~2
        }
        ACTIVE (Mic = 3) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 4
          Else
            Mixer6Mics = Mixer6Mics & ~4
        }
        ACTIVE (Mic = 4) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 8
          Else
            Mixer6Mics = Mixer6Mics & ~8
        }
        ACTIVE (Mic = 5) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 16
          Else
            Mixer6Mics = Mixer6Mics & ~16
        }
        ACTIVE (Mic = 6) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 32
          Else
            Mixer6Mics = Mixer6Mics & ~32
        }
        ACTIVE (Mic = 7) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 64
          Else
            Mixer6Mics = Mixer6Mics & ~64
        }
        ACTIVE (Mic = 8) :
        {
          IF (MicOn)
            Mixer6Mics = Mixer6Mics | 128
          Else
            Mixer6Mics = Mixer6Mics & ~128
        }
      }
    }
  }
}

(***************** Mixer Mics ******************)
(* This subroutine turns on the buttons that   *)
(* are stored in the parameter 'Mics'          *)
(***********************************************)
DEFINE_CALL 'MixerMics' (Mics)
{

  ON [TP,MASTER_MIC_OFF]   (* Clear the Master Mic *)
  MasterMic = 255
  IF (Mics & 1)
    ON [TP,MIC1_BTN]
  Else
    OFF[TP,MIC1_BTN]
  IF (Mics & 2)
    ON [TP,MIC2_BTN]
  Else
    OFF[TP,MIC2_BTN]
  IF (Mics & 4)
    ON [TP,MIC3_BTN]
  Else
    OFF[TP,MIC3_BTN]
  IF (Mics & 8)
    ON [TP,MIC4_BTN]
  Else
    OFF[TP,MIC4_BTN]
  IF (Mics & 16)
    ON [TP,MIC5_BTN]
  Else
    OFF[TP,MIC5_BTN]
  IF (Mics & 32)
    ON [TP,MIC6_BTN]
  Else
    OFF[TP,MIC6_BTN]
  IF (Mics & 64)
    ON [TP,MIC7_BTN]
  Else
    OFF[TP,MIC7_BTN]
  IF (Mics & 128)
    ON [TP,MIC8_BTN]
  Else
    OFF[TP,MIC8_BTN]
}

(*********** Clear System ****************)
(* Initializes system by clearing or setting all startup parameters *)
DEFINE_CALL 'ClearSystem'
{
  RaneInfo = "" (* Use this variable for system debug *)
  SYSTEM_CALL 'RaneIni' 
  (* Used to clear the level ontrol *)
  SYSTEM_CALL 'Rw232Vols'(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255)
  CALL 'ClearInputs'
  SET_LENGTH_STRING (KeyPadEntry,0)
  SEND_COMMAND TP,'TEXT2-|'
  CALL 'MixerMics' (0)  (* Clear Mics *)
  SEND_COMMAND TP,'ICON30-3'
  SEND_COMMAND TP,'ICON31-3'
  SEND_COMMAND TP,'ICON32-3'
  SEND_COMMAND TP,'ICON33-3'
  SEND_COMMAND TP,'ICON34-3'
  SEND_COMMAND TP,'ICON35-3'
  LastButton = 0
  OFF [TP,REMOTE_DIAG_BTN]
  OFF [TP,AUTO_DISCONNECT_BTN]
  OFF [TP,AUTO_ANSWER_BTN]
  OFF [TP,PAUSE_FLASH_BTN]
  ON [TP,RPM_SELECT_BTN]

  RPMmemory = MEM1_BTN
  RPEmemory = MEM1_BTN
  ON [TP,RPMmemory]
}

(*********** System Start ****************)
(* Initializes system by clearing or setting all startup parameters,
   recalling memory 1 port and mic settings for ECS, memory 1 for the RPD 1, *)
DEFINE_CALL 'SystemStart'
{
  (* Power-up system *)
  (* ON [RELAY,POWER] *)

  CALL 'ClearSystem'
  ON [TP,SYSTEM_ON_BTN]
  Input1 = 0
  Input2 = 0
  Input3 = 0
  Input4 = 0
  Input5 = 0
  Input6 = 0
  Output1 = 0
  Output2 = 0
  Output3 = 0
  Output4 = 0
  Output5 = 0
  Output6 = 0
  SetButtons  = 1
  Port1Inputs = 0
  Port2Inputs = 0
  Port3Inputs = 0
  Port4Inputs = 0
  Port5Inputs = 0
  Port6Inputs = 0
  MixOffset   = 0
  Mixer1Mics = 0
  Mixer2Mics = 0
  Mixer3Mics = 0
  Mixer4Mics = 0
  Mixer5Mics = 0
  Mixer6Mics = 0
  MasterMic  = 255 (* Start as new *) 
  MasterPort = 255
  OffHook    = 0
  StopOpstat = 0
  StopSR1    = 0
  SystemReady = 1
  SystemOn   = 1

  OFF[TP,SELECT_ROUTE_BTN]
  ON [TP,MIXER1_BTN]
  CALL 'ClearKey'
  CALL 'ClearSingleKey'
  (* Set Volume levels *)
  (* Recall Memory 1 on all units *)
              (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
  SYSTEM_CALL 'RW232_Q' (RW232_ALL_DEVICES, RW232_ALL_DEVICES, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1,0,"")
  OldPGMvolume        = 255
  OldCPGMvol          = 255
  OldECMvolume        = 255
  OldCECMvol          = 255
  Old_RPM_RPE_Volume  = 255
  OldRPMvolume        = 255
  OldCRPMvol          = 255
  OldRPEvolume        = 255
  OldCRPEvol          = 255

(* The TP Level will must be incremented to be changed.  *)

  PGMvolume      = 191 (* 10 dB ECB = 255 - ((ECB62 Volume = 20) * 255) / 80)  see RW Manual-26 *)
  ECMvolume      = 196 (* Reset PGMVolume to -10dB out* = ((ECMlevel-58) * 255)/60 [ECMlevel = 118-4-10 = 104] *)
  RPEvolume      = 128 (* 0 dB  = mid point *)
  RPMvolume      = 215 (* -10 dB = RPMVolume = 255 - (10*255/64) *)
  RPM_RPE_Volume = RPMvolume (* Reset Volume *)

  IF (PGMvolume)
  {
    SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume-1
    SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume
  }
  IF (ECMvolume)
  {
  SEND_LEVEL TP,ECM_VOL_BAR,ECMvolume-1
  SEND_LEVEL TP,ECM_VOL_BAR,ECMvolume
  }
  IF (RPM_RPE_Volume)
  {
    SEND_LEVEL TP,RPM_VOL_BAR,RPM_RPE_Volume-1
    SEND_LEVEL TP,RPM_VOL_BAR,RPM_RPE_Volume
  }
}

(*********** System Off ****************)
DEFINE_CALL 'SystemOff'
{
  (* Power-Down system *)
  (* OFF[RELAY,POWER] *)

(*  SEND_COMMAND TP,'PAGE-MAIN' *)
  ON [TP,SYSTEM_OFF_BTN]
  (* Recall Memory 1 on all units *)
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
  SYSTEM_CALL 'RW232_Q' (RW232_ALL_DEVICES, RW232_ALL_DEVICES, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1,0,"")


  (* Hangup *)
                  (* Device Type, Device Address, Command, Hybrid Command, 0, 0, Data = Off Hook *)
  SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_OFF_HOOK_CMD, 0, 0, "0")
  SystemReady = 0
  WAIT 10
  {
    CALL 'ClearSystem'
    SystemOn = 0
  }
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

CREATE_LEVEL TP, PGM_VOL_BAR, PGMVolume
CREATE_LEVEL TP, ECM_VOL_BAR, ECMvolume
CREATE_LEVEL TP, RPM_VOL_BAR, RPM_RPE_Volume

SEND_COMMAND RW232,'SET BAUD 19200,E,8,1 485 DISABLED'
SEND_COMMAND SR1,'SET BAUD 9600,N,8,1,485 ENABLE'
CREATE_BUFFER RW232, RW232rxBuffer
CREATE_BUFFER SR1, SR1rxBuffer

SEND_COMMAND TP,'PAGE-MAIN'

CREATE_BUFFER TP,TPbuf     (* Used for TP tracking *)
SEND_COMMAND TP,'TPAGEON'

WAIT 20
{
  CALL 'ClearSystem'
  SystemReady = 1
  SystemOn = 1
  CALL 'SystemOff'
}

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(* System On *)
PUSH [TP,SYSTEM_ON_BTN]
  IF (!([TP,SYSTEM_ON_BTN]))
    CALL 'SystemStart'

(* System Off *)
PUSH [TP,SYSTEM_OFF_BTN]
  CALL 'SystemOff'

    (* Resets the last button pressed if bad data is returned *)
    (* Set ButtonPushed to 0 if you do not want it reset *)
IF (BadRaneData)
{
  BadRaneData = 0
  IF (ButtonPushed)
  {
    IF ([TP,ButtonPushed])
      OFF[TP,ButtonPushed]
    ELSE
      ON [TP,ButtonPushed]
  }
}

IF (SystemOn && SystemReady)
{

  IF (StopOpstat)
    WAIT 10
      StopOpstat = StopOpstat - 1
(**************** Get OPSTATs ************************)
(*StopOpstat = 1*)
  IF (!StopOpstat)
  {

    WAIT 5    (* 500 ms *)
    {
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_GET_OPSTAT, 0, 0, 0, "")
    }

    WAIT 10  (* 1 Sec *)
    {
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_GET_OPSTAT, 0, 0, 0, "")
    }
  }

(**************** ECB OPSTAT ************************)

  (* The following is a demo using the Opstat message *)
  (* and can be used for a Multipoint video switch and *)
  (* video follows Mic audio *)
  IF (ECB62opstatReady)
  {
    ECB62opstatReady = 0
    IF (VUmeter <> RW232myData[6])
    {
      VUmeter = RW232myData[6]
    }

    IF (MasterPort <> RW232myData[7])
    {
      MasterPort = RW232myData[7]
      SELECT
      {
        ACTIVE (MasterPort = 0) :
          ON [TP,MASTER_PORT1]
        ACTIVE (MasterPort = 1) :
          ON [TP,MASTER_PORT2]
        ACTIVE (MasterPort = 2) :
          ON [TP,MASTER_PORT3]
        ACTIVE (MasterPort = 3) :
          ON [TP,MASTER_PORT4]
        ACTIVE (MasterPort = 4) :
          ON [TP,MASTER_PORT5]
        ACTIVE (MasterPort = 5) :
          ON [TP,MASTER_PORT6]
      }
    }

    IF (MasterMic <> RW232myData[8])
    {
      MasterMic = RW232myData[8]
      MasterMicLed = MasterMic
      SELECT
      {
        ACTIVE ([TP,MIXER2_BTN]) :
          MasterMicLed = MasterMic - 8
        ACTIVE ([TP,MIXER3_BTN]) :
          MasterMicLed = MasterMic - 16
        ACTIVE ([TP,MIXER4_BTN]) :
          MasterMicLed = MasterMic - 24
        ACTIVE ([TP,MIXER5_BTN]) :
          MasterMicLed = MasterMic - 32
        ACTIVE ([TP,MIXER6_BTN]) :
          MasterMicLed = MasterMic - 40
      }
      SELECT
      {
        ACTIVE (MasterMicLed = 0) :
          ON [TP,MASTER_MIC1]
        ACTIVE (MasterMicLed = 1) :
          ON [TP,MASTER_MIC2]
        ACTIVE (MasterMicLed = 2) :
          ON [TP,MASTER_MIC3]
        ACTIVE (MasterMicLed = 3) :
          ON [TP,MASTER_MIC4]
        ACTIVE (MasterMicLed = 4) :
          ON [TP,MASTER_MIC5]
        ACTIVE (MasterMicLed = 5) :
          ON [TP,MASTER_MIC6]
        ACTIVE (MasterMicLed = 6) :
          ON [TP,MASTER_MIC7]
        ACTIVE (MasterMicLed = 7) :
          ON [TP,MASTER_MIC8]
        ACTIVE (1) :
          ON [TP,MASTER_MIC_OFF]
      }
    }
  }   (*End ECB62opstatReady *)

(**************** ECM OPSTAT ************************)

  IF (ECM64opstatReady)
  {
    ECM64opstatReady = 0
    OffHook = RW232myData[7]
    [TP,OFF_HOOK] = OffHook
    (* Axcess bug - Beware this does not work IF (!OffHook && ECM64opstat[8]) *)
    IF ((!OffHook) && RW232myData[8])
    {
      SEND_COMMAND TP,'ABEEP'
      PULSE [TP,RING_LED]
      (* The following causes the page to flip to ECM Page *)
      IF (LENGTH_STRING(TPbuf))  (* Set page to ECM *)
      {
        IF (!(FIND_STRING (TPbuf,'-ECM',1)))
        {
          SEND_COMMAND TP,'PAGE-ECM'
        }
      }
    }
    DTMFrxNumber = RW232myData[14]
    (* CLEAR_BTN_BUFFER ECM64opstat *)
  }
(*********** End Opstats *************)

(**************** RaneWare Volume Controls **************)
 (* Rw232Vols Format *)   (* TP, Up Btn, Dwn Btn, Mute Btn, UnMute Btn, Device Type,
                          Device Address, SPL Index, Volume, OldVolume, OldCalVolume, Volume# *)
                       (* Set UnMute to 0 to use Mute as Toggle              *)
(****** ECB 62 Out 1's Volume Control *********)
  NewVolume = 1  (* Use NewVolume for both the volume # and if level has changed *)
                 (* NewVolume is set to 0 by Rw232Vols if level has not changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, PGM_UP_BTN, PGM_DWN_BTN, 0, 0, ECB_62, ECB62_ADDRESS,
                           ECB62_P1OUT_VOL, PGMVolume, OldPGMVolume, OldCPGMVol, NewVolume)

(****** ECM 64 Out 1's Volume Control *********)
  IF (!NewVolume) (* Do not do if previous volume is in use *)
  {
    NewVolume = 2  (* Use NewVolume for both the volume # and if level has changed *)
    SYSTEM_CALL 'Rw232Vols'(TP, ECM_UP_BTN, ECM_DWN_BTN, 0, 0, ECM_64, ECM64_ADDRESS,
                             ECM64_OUT1_LEVEL, ECMvolume, OldECMvolume, OldCECMvol, NewVolume)
    IF (NewVolume) (* NewVolume will be changed by system_call *)
      SEND_LEVEL TP,ECM_VOL_BAR,ECMvolume
  }

(****** RPM 26 and RPE 288d Volume Control *********)
  PUSH [TP,RPM_SELECT_BTN]
  {
    ON [TP,RPM_SELECT_BTN]
    RPM_RPE_Volume = RPMvolume
    Old_RPM_RPE_Volume = OldRPMvolume
    Old_RPM_RPE_Cvolume = OldCRPMvol
    ON [TP,RPMmemory]
    SEND_LEVEL TP,RPM_VOL_BAR,RPM_RPE_Volume
  }

  PUSH [TP,RPE_SELECT_BTN]
  {
    ON [TP,RPE_SELECT_BTN]
    RPM_RPE_Volume = RPEvolume
    Old_RPM_RPE_Volume = OldRPEvolume
    Old_RPM_RPE_Cvolume = OldCRPEvol
    ON [TP,RPEmemory]
    SEND_LEVEL TP,RPM_VOL_BAR,RPM_RPE_Volume
  }

  IF (!NewVolume)
  {
    NewVolume = 3  (* Use NewVolume for both the volume # and if level has changed *)
    IF ([TP,RPM_SELECT_BTN])
    {
      SYSTEM_CALL 'Rw232Vols'(TP, RPM_UP_BTN, RPM_DWN_BTN, 0, 0, RPM_26, RPM26_ADDRESS,
                               RPM_VOL, RPM_RPE_Volume, Old_RPM_RPE_Volume, Old_RPM_RPE_Cvolume, NewVolume)
    }
    ELSE        (* Both Left and Right channels are controlled with this call *)
    { (* SPL RPE_VOL = Both Channels, RPE_VOL1 = Channel1, RPE_VOL2 = Channel 2 *)
      SYSTEM_CALL 'Rw232Vols'(TP, RPM_UP_BTN, RPM_DWN_BTN, 0, 0, RPE_228, RPE228_ADDRESS,
                               RPE_VOL, RPM_RPE_Volume, Old_RPM_RPE_Volume, Old_RPM_RPE_Cvolume, NewVolume)
    }
  }

  IF (NewVolume) (* Volume has changed by Rw232Vols - set SR 1 *)
  {
(****** SR 1L Control for ECB 62 and RPM 26/RPE 288d Volume Control *********)
                   (* Flip volume 255 = 0, 0 = 255, Scale steps *)
    SR1level[1] = 30 - ((PGMvolume*30)/255)
    SR1level[2] = 30 - ((RPM_RPE_Volume*30)/255)
    IF (SR1level[1] <> OldSR1level[1])  (* Change Remote level*)
    {
      OldSR1level[1] = SR1level[1]
      SYSTEM_CALL 'SR1_Q' (1,SR1_CMD_FORCE,SR1level[1])
    }
    IF (SR1level[2] <> OldSR1level[2])  (* Change Remote level*)
    {
      OldSR1level[2] = SR1level[2]
      SYSTEM_CALL 'SR1_Q' (2,SR1_CMD_FORCE,SR1level[2])
    }
  }
  ELSE  (* Get SR1 *)
  {
    IF (SR1level[1] <> OldSR1level[1])  (* Test for change of level at remote *)
    {
      OldSR1level[1] = SR1level[1]
      PGMvolume = ((30 - SR1level[1]) * 255)/30
      NewVolume = 1        (* Only perform level *)
      SYSTEM_CALL 'Rw232Vols'(0, 0, 0, 0, 0, ECB_62, ECB62_ADDRESS,
                           ECB62_P1OUT_VOL, PGMVolume, OldPGMVolume, OldCPGMVol, NewVolume)
      IF (NewVolume)
      {
        NewVolume = 0
        StopOpstat = 2
        SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume
      }
    }
    IF (SR1level[2] <> OldSR1level[2])  (* Test for change of level at remote *)
    {
      OldSR1level[2] = SR1level[2]
      RPM_RPE_Volume = ((30 - SR1level[2]) * 255)/30
      NewVolume = 3  (* Use NewVolume for both the volume # and if level has changed *)
      IF ([TP,RPM_SELECT_BTN])
      {                  (* Only perform level *)
        SYSTEM_CALL 'Rw232Vols'(0, 0, 0, 0, 0, RPM_26, RPM26_ADDRESS,
                             RPM_VOL, RPM_RPE_Volume, Old_RPM_RPE_Volume, Old_RPM_RPE_Cvolume, NewVolume)
        IF (NewVolume)
        {
          NewVolume = 0
          StopOpstat = 2
          SEND_LEVEL TP,RPM_VOL_BAR,RPM_RPE_Volume
          RPMvolume = RPM_RPE_Volume
          OldRPMvolume = Old_RPM_RPE_Volume
          OldCRPMvol = Old_RPM_RPE_Cvolume
        }
      }
      ELSE
      {                      (* Only perform level *)
        SYSTEM_CALL 'Rw232Vols'(0, 0, 0, 0, 0, RPE_228, RPE228_ADDRESS,
                             RPE_VOL, RPM_RPE_Volume, Old_RPM_RPE_Volume, Old_RPM_RPE_Cvolume, NewVolume)
        IF (NewVolume)
        {
          NewVolume = 0
          StopOpstat = 2
          SEND_LEVEL TP,RPM_VOL_BAR,RPM_RPE_Volume
          RPEvolume = RPM_RPE_Volume
          OldRPEvolume = Old_RPM_RPE_Volume
          OldCRPEvol = Old_RPM_RPE_Cvolume
        }
      }
    }
  }

  IF (NewVolume)
  {
    NewVolume = 0
    StopOpstat = 2
    StopSR1 = 2
    IF ([TP,RPM_SELECT_BTN])
    {
      RPMvolume = RPM_RPE_Volume
      OldRPMvolume = Old_RPM_RPE_Volume
      OldCRPMvol = Old_RPM_RPE_Cvolume
    }
    ELSE
    {
      RPEvolume = RPM_RPE_Volume
      OldRPEvolume = Old_RPM_RPE_Volume
      OldCRPEvol = Old_RPM_RPE_Cvolume
    }
    SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume
    SEND_LEVEL TP,RPM_VOL_BAR,RPM_RPE_Volume
  }

   (**************** Mic Buttons ************************)

        (* The Mic buttons turns the Mic's Active On/Off *)
        (* Use the RW232 program to set the Mic's Mode type *)
        (* Auto for voice detection or On to Force the Mic On *)
  PUSH [TP,MIXER1_BTN]
  {
    ON [TP,MIXER1_BTN]
    MixOffset = 0
    CALL 'MixerMics' (Mixer1Mics)
  }

  PUSH [TP,MIXER2_BTN]
  {
    ON [TP,MIXER2_BTN]
    MixOffset = ECB62_MIX_OFFSET
    CALL 'MixerMics' (Mixer2Mics)
  }

  PUSH [TP,MIXER3_BTN]
  {
    ON [TP,MIXER3_BTN]
    MixOffset = ECB62_MIX_OFFSET * 2
    CALL 'MixerMics' (Mixer3Mics)
  }

  PUSH [TP,MIXER4_BTN]
  {
    ON [TP,MIXER4_BTN]
    MixOffset = ECB62_MIX_OFFSET * 3
    CALL 'MixerMics' (Mixer4Mics)
  }

  PUSH [TP,MIXER5_BTN]
  {
    ON [TP,MIXER5_BTN]
    MixOffset = ECB62_MIX_OFFSET * 4
    CALL 'MixerMics' (Mixer5Mics)
  }

  PUSH [TP,MIXER6_BTN]
  {
    ON [TP,MIXER6_BTN]
    MixOffset = ECB62_MIX_OFFSET * 5
    CALL 'MixerMics' (Mixer6Mics)
  }

  PUSH [TP,MIC1_BTN]
  {
    IF (!([TP,MIC1_BTN]))
    {
      RW232data = 1
      ON [TP,MIC1_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC1_BTN]
    }
    ButtonPushed = MIC1_BTN
    CALL 'SetMic' (RW232data,1,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

  PUSH [TP,MIC2_BTN]
  {
    IF (!([TP,MIC2_BTN]))
    {
      RW232data = 1
      ON [TP,MIC2_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC2_BTN]
    }
    ButtonPushed = MIC2_BTN
    CALL 'SetMic' (RW232data,2,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           ECB62_MIC_OFFSET + ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

  PUSH [TP,MIC3_BTN]
  {
    IF (!([TP,MIC3_BTN]))
    {
      RW232data = 1
      ON [TP,MIC3_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC3_BTN]
    }
    ButtonPushed = MIC3_BTN
    CALL 'SetMic' (RW232data,3,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           2*ECB62_MIC_OFFSET + ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

  PUSH [TP,MIC4_BTN]
  {
    IF (!([TP,MIC4_BTN]))
    {
      RW232data = 1
      ON [TP,MIC4_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC4_BTN]
    }
    ButtonPushed = MIC4_BTN
    CALL 'SetMic' (RW232data,4,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           3*ECB62_MIC_OFFSET + ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

  PUSH [TP,MIC5_BTN]
  {
    IF (!([TP,MIC5_BTN]))
    {
      RW232data = 1
      ON [TP,MIC5_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC5_BTN]
    }
    ButtonPushed = MIC5_BTN
    CALL 'SetMic' (RW232data,5,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           4*ECB62_MIC_OFFSET + ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

  PUSH [TP,MIC6_BTN]
  {
    IF (!([TP,MIC6_BTN]))
    {
      RW232data = 1
      ON [TP,MIC6_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC6_BTN]
    }
    ButtonPushed = MIC6_BTN
    CALL 'SetMic' (RW232data,6,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           5*ECB62_MIC_OFFSET + ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

  PUSH [TP,MIC7_BTN]
  {
    IF (!([TP,MIC7_BTN]))
    {
      RW232data = 1
      ON [TP,MIC7_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC7_BTN]
    }
    ButtonPushed = MIC7_BTN
    CALL 'SetMic' (RW232data,7,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           6*ECB62_MIC_OFFSET + ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

  PUSH [TP,MIC8_BTN]
  {
    IF (!([TP,MIC8_BTN]))
    {
      RW232data = 1
      ON [TP,MIC8_BTN]
    }
    ELSE
    {
      RW232data = 0
      OFF[TP,MIC8_BTN]
    }
    ButtonPushed = MIC8_BTN
    CALL 'SetMic' (RW232data,8,MixOffset)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           7*ECB62_MIC_OFFSET + ECB62_MIC1_ACTIVE + MixOffset, "RW232data")
  }

    (*********** FORCE MICS On/Auto ****************)

  PUSH [TP,FORCE_MIC1_BTN]
  {
    RW232data = 1       (* Forced On *)
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  PUSH [TP,FORCE_MIC2_BTN]
  {
    RW232data = 1
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  PUSH [TP,FORCE_MIC3_BTN]
  {
    RW232data = 1
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           2*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  PUSH [TP,FORCE_MIC4_BTN]
  {
    RW232data = 1
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           3*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  PUSH [TP,FORCE_MIC5_BTN]
   {
    RW232data = 1
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           4*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  PUSH [TP,FORCE_MIC6_BTN]
  {
    RW232data = 1
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           5*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")

  }

  PUSH [TP,FORCE_MIC7_BTN]
  {
    RW232data = 1
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           6*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  PUSH [TP,FORCE_MIC8_BTN]
  {
    RW232data = 1
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           7*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC1_BTN]
  {
    RW232data = 2  (* Auto *)
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC2_BTN]
  {
    RW232data = 2
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC3_BTN]
  {
    RW232data = 2
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           2*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC4_BTN]
  {
    RW232data = 2
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           3*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC5_BTN]
  {
    RW232data = 2
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           4*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC6_BTN]
  {
    RW232data = 2
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           5*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC7_BTN]
  {
    RW232data = 2
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           6*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }

  RELEASE[TP,FORCE_MIC8_BTN]
  {
    RW232data = 2
    ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0,
                           7*ECB62_MIC_OFFSET + ECB62_MIC1_MODE + MixOffset, "RW232data")
  }


  PUSH [TP,SELECT_ROUTE_BTN]
  {
    IF (!([TP,SELECT_ROUTE_BTN]))
    {
      ON [TP,SELECT_ROUTE_BTN]
      OFF[TP,PORT1_OUT_BTN]
      OFF[TP,PORT2_OUT_BTN]
      OFF[TP,PORT3_OUT_BTN]
      OFF[TP,PORT4_OUT_BTN]
      OFF[TP,PORT5_OUT_BTN]
      OFF[TP,PORT6_OUT_BTN]
      CALL 'ClearInputs'
    }
    ELSE
      OFF[TP,SELECT_ROUTE_BTN]
  }

        (* When the SELECT_ROUTE_BTN button is off, selecting a Port turns the *)
        (* Port Input On/Off. *)

  IF (!([TP,SELECT_ROUTE_BTN]))
  {
    SetButtons = 1
    IF (SetButtons)
    {
      SetButtons = 0
      CALL 'ResetLast'

      IF (Input1)
        ON [TP,PORT1_IN_BTN]
      ELSE
        OFF[TP,PORT1_IN_BTN]

      IF (Input2)
        ON [TP,PORT2_IN_BTN]
      ELSE
        OFF[TP,PORT2_IN_BTN]

      IF (Input3)
        ON [TP,PORT3_IN_BTN]
      ELSE
        OFF[TP,PORT3_IN_BTN]

      IF (Input4)
        ON [TP,PORT4_IN_BTN]
      ELSE
        OFF[TP,PORT4_IN_BTN]

      IF (Input5)
        ON [TP,PORT5_IN_BTN]
      ELSE
        OFF[TP,PORT5_IN_BTN]

      IF (Input6)
        ON [TP,PORT6_IN_BTN]
      ELSE
        OFF[TP,PORT6_IN_BTN]

      IF (Output1)
        ON [TP,PORT1_OUT_BTN]
      ELSE
        OFF[TP,PORT1_OUT_BTN]

      IF (Output2)
        ON [TP,PORT2_OUT_BTN]
      ELSE
        OFF[TP,PORT2_OUT_BTN]

      IF (Output3)
        ON [TP,PORT3_OUT_BTN]
      ELSE
        OFF[TP,PORT3_OUT_BTN]

      IF (Output4)
        ON [TP,PORT4_OUT_BTN]
      ELSE
        OFF[TP,PORT4_OUT_BTN]

      IF (Output5)
        ON [TP,PORT5_OUT_BTN]
      ELSE
        OFF[TP,PORT5_OUT_BTN]

      IF (Output6)
        ON [TP,PORT6_OUT_BTN]
      ELSE
        OFF[TP,PORT6_OUT_BTN]
    }  (* End SetButtons *)

    PUSH [TP,PORT1_IN_BTN]   (* PORT 1 INPUT *)
    {
      IF (!([TP,PORT1_IN_BTN]))
      {
        RW232data = 1
        ON [TP,PORT1_IN_BTN]
        Input1 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT1_IN_BTN]
        Input1 = 0
      }
      ButtonPushed = PORT1_IN_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1IN_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT2_IN_BTN]   (* PORT 2 INPUT *)
    {
      IF (!([TP,PORT2_IN_BTN]))
      {
        RW232data = 1
        ON [TP,PORT2_IN_BTN]
        Input2 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT2_IN_BTN]
        Input2 = 0
      }
      ButtonPushed = PORT2_IN_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P2IN_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT3_IN_BTN]   (* PORT 3 INPUT *)
    {
      IF (!([TP,PORT3_IN_BTN]))
      {
        RW232data = 1
        ON [TP,PORT3_IN_BTN]
        Input3 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT3_IN_BTN]
        Input3 = 0
      }
      ButtonPushed = PORT3_IN_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P3IN_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT4_IN_BTN]   (* PORT 4 INPUT *)
    {
      IF (!([TP,PORT4_IN_BTN]))
      {
        RW232data = 1
        ON [TP,PORT4_IN_BTN]
        Input4 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT4_IN_BTN]
        Input4 = 0
      }
      ButtonPushed = PORT4_IN_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P4IN_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT5_IN_BTN]   (* PORT 5 INPUT *)
    {
      IF (!([TP,PORT5_IN_BTN]))
      {
        RW232data = 1
        ON [TP,PORT5_IN_BTN]
        Input5 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT5_IN_BTN]
        Input5 = 0
      }
      ButtonPushed = PORT5_IN_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1IN_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT6_IN_BTN]   (* PORT 6 INPUT *)
    {
      IF (!([TP,PORT6_IN_BTN]))
      {
        RW232data = 1
        ON [TP,PORT6_IN_BTN]
        Input6 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT6_IN_BTN]
        Input6 = 0
      }
      ButtonPushed = PORT6_IN_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P6IN_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT1_OUT_BTN]   (* PORT 1 OUTPUT *)
    {
      IF (!([TP,PORT1_OUT_BTN]))
      {
        RW232data = 1
        ON [TP,PORT1_OUT_BTN]
        Output1 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT1_OUT_BTN]
        Output1 = 0
      }
      ButtonPushed = PORT1_OUT_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1OUT_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT2_OUT_BTN]   (* PORT 2 OUTPUT *)
    {
      IF (!([TP,PORT2_OUT_BTN]))
      {
        RW232data = 1
        ON [TP,PORT2_OUT_BTN]
        Output2 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT2_OUT_BTN]
        Output2 = 0
      }
      ButtonPushed = PORT2_OUT_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P2OUT_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT3_OUT_BTN]   (* PORT 3 OUTPUT *)
    {
      IF (!([TP,PORT3_OUT_BTN]))
      {
        RW232data = 1
        ON [TP,PORT3_OUT_BTN]
        Output3 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT3_OUT_BTN]
        Output3 = 0
      }
      ButtonPushed = PORT3_OUT_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P3OUT_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT4_OUT_BTN]   (* PORT 4 OUTPUT *)
    {
      IF (!([TP,PORT4_OUT_BTN]))
      {
        RW232data = 1
        ON [TP,PORT4_OUT_BTN]
        Output4 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT4_OUT_BTN]
        Output4 = 0
      }
      ButtonPushed = PORT4_OUT_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P4OUT_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT5_OUT_BTN]   (* PORT 5 OUTPUT *)
    {
      IF (!([TP,PORT5_OUT_BTN]))
      {
        RW232data = 1
        ON [TP,PORT5_OUT_BTN]
        Output5 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT5_OUT_BTN]
        Output5 = 0
      }
      ButtonPushed = PORT5_OUT_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P5OUT_ON_OFF, "RW232data")
    }

    PUSH [TP,PORT6_OUT_BTN]   (* PORT 6 OUTPUT *)
    {
      IF (!([TP,PORT6_OUT_BTN]))
      {
        RW232data = 1
        ON [TP,PORT6_OUT_BTN]
        Output6 = 1
      }
      ELSE
      {
        RW232data = 0
        OFF[TP,PORT6_OUT_BTN]
        Output6 = 0
      }
      ButtonPushed = PORT6_OUT_BTN
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P6OUT_ON_OFF, "RW232data")
    }
  }   (* End PORTS ON/OFF *)

        (* When the SELECT_ROUTE_BTN button is on, selecting a Port Output button *)
        (* allows for the selection of its Input Ports *)

  ELSE   (* Input Select on *)
  {
    (* MAKE PORTS READY *)
    PUSH [TP,PORT1_OUT_BTN]   (* PORT 1 OUTPUT *)
    {
      IF (!([TP,PORT1_OUT_BTN]))
      {
        ON [TP,PORT1_OUT_BTN]
        SEND_COMMAND TP,'ICON30-0'
        CALL 'ResetLast'
        LastButton = PORT1_IN_BTN
        CALL 'ClearInputs'
        OFF[TP,PORT2_OUT_BTN]
        OFF[TP,PORT3_OUT_BTN]
        OFF[TP,PORT4_OUT_BTN]
        OFF[TP,PORT5_OUT_BTN]
        OFF[TP,PORT6_OUT_BTN]
        IF (Port1Inputs & 1)
          ON [TP,PORT2_IN_BTN]
        IF (Port1Inputs & 2)
          ON [TP,PORT3_IN_BTN]
        IF (Port1Inputs & 4)
          ON [TP,PORT4_IN_BTN]
        IF (Port1Inputs & 8)
          ON [TP,PORT5_IN_BTN]
        IF (Port1Inputs & 16)
          ON [TP,PORT6_IN_BTN]
      }
    }

    PUSH [TP,PORT2_OUT_BTN]   (* PORT 2 OUTPUT *)
    {
      IF (!([TP,PORT2_OUT_BTN]))
      {
        ON [TP,PORT2_OUT_BTN]
        SEND_COMMAND TP,'ICON31-0'
        CALL 'ResetLast'
        LastButton = PORT2_IN_BTN
        CALL 'ClearInputs'
        OFF[TP,PORT1_OUT_BTN]
        OFF[TP,PORT3_OUT_BTN]
        OFF[TP,PORT4_OUT_BTN]
        OFF[TP,PORT5_OUT_BTN]
        OFF[TP,PORT6_OUT_BTN]
        IF (Port2Inputs & 1)
          ON [TP,PORT1_IN_BTN]
        IF (Port2Inputs & 2)
          ON [TP,PORT3_IN_BTN]
        IF (Port2Inputs & 4)
          ON [TP,PORT4_IN_BTN]
        IF (Port2Inputs & 8)
          ON [TP,PORT5_IN_BTN]
        IF (Port2Inputs & 16)
          ON [TP,PORT6_IN_BTN]
      }
    }

    PUSH [TP,PORT3_OUT_BTN]   (* PORT 3 OUTPUT *)
    {
      IF (!([TP,PORT3_OUT_BTN]))
      {
        ON [TP,PORT3_OUT_BTN]
        SEND_COMMAND TP,'ICON32-0'
        CALL 'ResetLast'
        LastButton = PORT3_IN_BTN
        CALL 'ClearInputs'
        OFF[TP,PORT1_OUT_BTN]
        OFF[TP,PORT2_OUT_BTN]
        OFF[TP,PORT4_OUT_BTN]
        OFF[TP,PORT5_OUT_BTN]
        OFF[TP,PORT6_OUT_BTN]
        IF (Port3Inputs & 1)
          ON [TP,PORT1_IN_BTN]
        IF (Port3Inputs & 2)
          ON [TP,PORT2_IN_BTN]
        IF (Port3Inputs & 4)
          ON [TP,PORT4_IN_BTN]
        IF (Port3Inputs & 8)
          ON [TP,PORT5_IN_BTN]
        IF (Port3Inputs & 16)
          ON [TP,PORT6_IN_BTN]
      }
    }

    PUSH [TP,PORT4_OUT_BTN]   (* PORT 4 OUTPUT *)
    {
      IF (!([TP,PORT4_OUT_BTN]))
      {
        ON [TP,PORT4_OUT_BTN]
        SEND_COMMAND TP,'ICON33-0'
        CALL 'ResetLast'
        LastButton = PORT4_IN_BTN
        CALL 'ClearInputs'
        OFF[TP,PORT1_OUT_BTN]
        OFF[TP,PORT2_OUT_BTN]
        OFF[TP,PORT3_OUT_BTN]
        OFF[TP,PORT5_OUT_BTN]
        OFF[TP,PORT6_OUT_BTN]
        IF (Port4Inputs & 1)
          ON [TP,PORT1_IN_BTN]
        IF (Port4Inputs & 2)
          ON [TP,PORT2_IN_BTN]
        IF (Port4Inputs & 4)
          ON [TP,PORT3_IN_BTN]
        IF (Port4Inputs & 8)
          ON [TP,PORT5_IN_BTN]
        IF (Port4Inputs & 16)
          ON [TP,PORT6_IN_BTN]
      }
    }

    PUSH [TP,PORT5_OUT_BTN]   (* PORT 5 OUTPUT *)
    {
      IF (!([TP,PORT5_OUT_BTN]))
      {
        ON [TP,PORT5_OUT_BTN]
        (* SEND_COMMAND TP,'ICON34-0' *)
        CALL 'ResetLast'
        LastButton = PORT5_IN_BTN
        CALL 'ClearInputs'
        OFF[TP,PORT1_OUT_BTN]
        OFF[TP,PORT2_OUT_BTN]
        OFF[TP,PORT3_OUT_BTN]
        OFF[TP,PORT4_OUT_BTN]
        OFF[TP,PORT6_OUT_BTN]
        IF (Port5Inputs & 1)
          ON [TP,PORT1_IN_BTN]
        IF (Port5Inputs & 2)
          ON [TP,PORT2_IN_BTN]
        IF (Port5Inputs & 4)
          ON [TP,PORT3_IN_BTN]
        IF (Port5Inputs & 8)
          ON [TP,PORT4_IN_BTN]
        IF (Port5Inputs & 16)
          ON [TP,PORT6_IN_BTN]
        IF (Port5Inputs & 32)
          ON [TP,PORT5_IN_BTN]
      }
    }

    PUSH [TP,PORT6_OUT_BTN]   (* PORT 6 OUTPUT *)
    {
      IF (!([TP,PORT6_OUT_BTN]))
      {
        ON [TP,PORT6_OUT_BTN]
        SEND_COMMAND TP,'ICON35-0'
        CALL 'ResetLast'
        LastButton = PORT6_IN_BTN
        CALL 'ClearInputs'
        OFF[TP,PORT1_OUT_BTN]
        OFF[TP,PORT2_OUT_BTN]
        OFF[TP,PORT3_OUT_BTN]
        OFF[TP,PORT4_OUT_BTN]
        OFF[TP,PORT5_OUT_BTN]
        IF (Port6Inputs & 1)
          ON [TP,PORT1_IN_BTN]
        IF (Port6Inputs & 2)
          ON [TP,PORT2_IN_BTN]
        IF (Port6Inputs & 4)
          ON [TP,PORT3_IN_BTN]
        IF (Port6Inputs & 8)
          ON [TP,PORT4_IN_BTN]
        IF (Port6Inputs & 16)
          ON [TP,PORT5_IN_BTN]
      }
    }

    IF ([TP,PORT1_OUT_BTN])   (* Port 1 input select *)
    {
      PUSH [TP,PORT2_IN_BTN]   (* PORT 2 of 1 *)
      {
        IF (!([TP,PORT2_IN_BTN]))
        {
          ON [TP,PORT2_IN_BTN]
          Port1Inputs = Port1Inputs | 1
        }
        ELSE
        {
          OFF[TP,PORT2_IN_BTN]
          Port1Inputs = Port1Inputs & ~1
        }
        ButtonPushed = PORT2_IN_BTN
        RW232data = Port1Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1_SELECT, "RW232data")
      }

      PUSH [TP,PORT3_IN_BTN]   (* PORT 3 of 1 *)
      {
        IF (!([TP,PORT3_IN_BTN]))
        {
          ON [TP,PORT3_IN_BTN]
          Port1Inputs = Port1Inputs | 2
        }
        ELSE
        {
          OFF[TP,PORT3_IN_BTN]
          Port1Inputs = Port1Inputs & ~2
        }
        ButtonPushed = PORT3_IN_BTN
        RW232data = Port1Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1_SELECT, "RW232data")
      }

      PUSH [TP,PORT4_IN_BTN]   (* PORT 4 of 1 *)
      {
        IF (!([TP,PORT4_IN_BTN]))
        {
          ON [TP,PORT4_IN_BTN]
          Port1Inputs = Port1Inputs | 4
        }
        ELSE
        {
          OFF[TP,PORT4_IN_BTN]
          Port1Inputs = Port1Inputs & ~4
        }
        ButtonPushed = PORT4_IN_BTN
        RW232data = Port1Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1_SELECT, "RW232data")
      }

      PUSH [TP,PORT5_IN_BTN]   (* PORT 5 of 1 *)
      {
        IF (!([TP,PORT5_IN_BTN]))
        {
          ON [TP,PORT5_IN_BTN]
          Port1Inputs = Port1Inputs | 8
        }
        ELSE
        {
          OFF[TP,PORT5_IN_BTN]
          Port1Inputs = Port1Inputs & ~8
        }
        ButtonPushed = PORT5_IN_BTN
        RW232data = Port1Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1_SELECT, "RW232data")
      }

      PUSH [TP,PORT6_IN_BTN]   (* PORT 6 of 1 *)
      {
        IF (!([TP,PORT6_IN_BTN]))
        {
          ON [TP,PORT6_IN_BTN]
          Port1Inputs = Port1Inputs | 16
        }
        ELSE
        {
          OFF[TP,PORT6_IN_BTN]
          Port1Inputs = Port1Inputs & ~16
        }
        ButtonPushed = PORT6_IN_BTN
        RW232data = Port1Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P1_SELECT, "RW232data")
      }
    }    (* End Port 1 Input Select *)

    IF ([TP,PORT2_OUT_BTN])   (* Port 2 Input Select *)
    {
      PUSH [TP,PORT1_IN_BTN]   (* PORT 1 of 2 *)
      {
        IF (!([TP,PORT1_IN_BTN]))
        {
          ON [TP,PORT1_IN_BTN]
          Port2Inputs = Port2Inputs | 1
        }
        ELSE
        {
          OFF[TP,PORT1_IN_BTN]
          Port2Inputs = Port2Inputs & ~1
        }
        ButtonPushed = PORT1_IN_BTN
        RW232data = Port2Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P2_SELECT, "RW232data")
      }

      PUSH [TP,PORT3_IN_BTN]   (* PORT 3 of 2 *)
      {
        IF (!([TP,PORT3_IN_BTN]))
        {
          ON [TP,PORT3_IN_BTN]
          Port2Inputs = Port2Inputs | 2
        }
        ELSE
        {
          OFF[TP,PORT3_IN_BTN]
          Port2Inputs = Port2Inputs & ~2
        }
        ButtonPushed = PORT3_IN_BTN
        RW232data = Port2Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P2_SELECT, "RW232data")
      }

      PUSH [TP,PORT4_IN_BTN]   (* PORT 4 of 2 *)
      {
        IF (!([TP,PORT4_IN_BTN]))
        {
          ON [TP,PORT4_IN_BTN]
          Port2Inputs = Port2Inputs | 4
        }
        ELSE
        {
          OFF[TP,PORT4_IN_BTN]
          Port2Inputs = Port2Inputs & ~4
        }
        ButtonPushed = PORT4_IN_BTN
        RW232data = Port2Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P2_SELECT, "RW232data")
      }

      PUSH [TP,PORT5_IN_BTN] (* PORT 5 of 2 *)
      {
        IF (!([TP,PORT5_IN_BTN]))
        {
          ON [TP,PORT5_IN_BTN]
          Port2Inputs = Port2Inputs | 8
        }
        ELSE
        {
          OFF[TP,PORT5_IN_BTN]
          Port2Inputs = Port2Inputs & ~8
        }
        ButtonPushed = PORT5_IN_BTN
        RW232data = Port2Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P2_SELECT, "RW232data")
      }

      PUSH [TP,PORT6_IN_BTN]   (* PORT 6 of 2 *)
      {
        IF (!([TP,PORT6_IN_BTN]))
        {
          ON [TP,PORT6_IN_BTN]
          Port2Inputs = Port2Inputs | 16
        }
        ELSE
        {
          OFF[TP,PORT6_IN_BTN]
          Port2Inputs = Port2Inputs & ~16
        }
        ButtonPushed = PORT6_IN_BTN
        RW232data = Port2Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P2_SELECT, "RW232data")
      }
    }    (* End Port 2 Input Select *)

    IF ([TP,PORT3_OUT_BTN])   (* Port 3 Input Select *)
    {
      PUSH [TP,PORT1_IN_BTN]   (* PORT 1 of 3 *)
      {
        IF (!([TP,PORT1_IN_BTN]))
        {
          ON [TP,PORT1_IN_BTN]
          Port3Inputs = Port3Inputs | 1
        }
        ELSE
        {
          OFF[TP,PORT1_IN_BTN]
          Port3Inputs = Port3Inputs & ~1
        }
        ButtonPushed = PORT1_IN_BTN
        RW232data = Port3Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P3_SELECT, "RW232data")
      }

      PUSH [TP,PORT2_IN_BTN]   (* PORT 2 of 3 *)
      {
        IF (!([TP,PORT2_IN_BTN]))
        {
          ON [TP,PORT2_IN_BTN]
          Port3Inputs = Port3Inputs | 2
        }
        ELSE
        {
          OFF[TP,PORT2_IN_BTN]
          Port3Inputs = Port3Inputs & ~2
        }
        ButtonPushed = PORT2_IN_BTN
        RW232data = Port3Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P3_SELECT, "RW232data")
      }

      PUSH [TP,PORT4_IN_BTN]   (* PORT 4 of 3 *)
      {
        IF (!([TP,PORT4_IN_BTN]))
        {
          ON [TP,PORT4_IN_BTN]
          Port3Inputs = Port3Inputs | 4
        }
        ELSE
        {
          OFF[TP,PORT4_IN_BTN]
          Port3Inputs = Port3Inputs & ~4
        }
        ButtonPushed = PORT4_IN_BTN
        RW232data = Port3Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P3_SELECT, "RW232data")
      }

      PUSH [TP,PORT5_IN_BTN]   (* PORT 5 of 3 *)
      {
        IF (!([TP,PORT5_IN_BTN]))
        {
          ON [TP,PORT5_IN_BTN]
          Port3Inputs = Port3Inputs | 8
        }
        ELSE
        {
          OFF[TP,PORT5_IN_BTN]
          Port3Inputs = Port3Inputs & ~8
        }
        ButtonPushed = PORT5_IN_BTN
        RW232data = Port3Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P3_SELECT, "RW232data")
      }

      PUSH [TP,PORT6_IN_BTN]   (* PORT 6 of 3 *)
      {
        IF (!([TP,PORT6_IN_BTN]))
        {
          ON [TP,PORT6_IN_BTN]
          Port3Inputs = Port3Inputs | 16
        }
        ELSE
        {
          OFF[TP,PORT6_IN_BTN]
          Port3Inputs = Port3Inputs & ~16
        }
        ButtonPushed = PORT6_IN_BTN
        RW232data = Port3Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P3_SELECT, "RW232data")
      }
    }    (* End Port 3 Input Select *)

    IF ([TP,PORT4_OUT_BTN])   (* Port 4 Input Select *)
    {
      PUSH [TP,PORT1_IN_BTN]   (* PORT 1 of 4 *)
      {
        IF (!([TP,PORT1_IN_BTN]))
        {
          ON [TP,PORT1_IN_BTN]
          Port4Inputs = Port4Inputs | 1
        }
        ELSE
        {
          OFF[TP,PORT1_IN_BTN]
          Port4Inputs = Port4Inputs & ~1
        }
        ButtonPushed = PORT1_IN_BTN
        RW232data = Port4Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P4_SELECT, "RW232data")
      }

      PUSH [TP,PORT2_IN_BTN]   (* PORT 2 of 4 *)
      {
        IF (!([TP,PORT2_IN_BTN]))
        {
          ON [TP,PORT2_IN_BTN]
          Port4Inputs = Port4Inputs | 2
        }
        ELSE
        {
          OFF[TP,PORT2_IN_BTN]
          Port4Inputs = Port4Inputs & ~2
        }
        ButtonPushed = PORT2_IN_BTN
        RW232data = Port4Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P4_SELECT, "RW232data")
      }

      PUSH [TP,PORT3_IN_BTN]   (* PORT 3 of 4 *)
      {
        IF (!([TP,PORT3_IN_BTN]))
        {
          ON [TP,PORT3_IN_BTN]
          Port4Inputs = Port4Inputs | 4
        }
        ELSE
        {
          OFF[TP,PORT3_IN_BTN]
          Port4Inputs = Port4Inputs & ~4
        }
        ButtonPushed = PORT3_IN_BTN
        RW232data = Port4Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P4_SELECT, "RW232data")
      }

      PUSH [TP,PORT5_IN_BTN]   (* PORT 5 of 4 *)
      {
        IF (!([TP,PORT5_IN_BTN]))
        {
          ON [TP,PORT5_IN_BTN]
          Port4Inputs = Port4Inputs | 8
        }
        ELSE
        {
          OFF[TP,PORT5_IN_BTN]
          Port4Inputs = Port4Inputs & ~8
        }
        ButtonPushed = PORT5_IN_BTN
        RW232data = Port4Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P4_SELECT, "RW232data")
      }

      PUSH [TP,PORT6_IN_BTN]   (* PORT 6 of 4 *)
      {
        IF (!([TP,PORT6_IN_BTN]))
        {
          ON [TP,PORT6_IN_BTN]
          Port4Inputs = Port4Inputs | 16
        }
        ELSE
        {
          OFF[TP,PORT6_IN_BTN]
          Port4Inputs = Port4Inputs & ~16
        }
        ButtonPushed = PORT6_IN_BTN
        RW232data = Port4Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P4_SELECT, "RW232data")
      }
    }    (* End Port 4 Input Select *)

    IF ([TP,PORT5_OUT_BTN])   (* Port 5 Input Select *)
    {
      PUSH [TP,PORT1_IN_BTN]   (* PORT 1 of 5 *)
      {
        IF (!([TP,PORT1_IN_BTN]))
        {
          ON [TP,PORT1_IN_BTN]
          Port5Inputs = Port5Inputs | 1
        }
        ELSE
        {
          OFF[TP,PORT1_IN_BTN]
          Port5Inputs = Port5Inputs & ~1
        }
        ButtonPushed = PORT1_IN_BTN
        RW232data = Port5Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P5_SELECT, "RW232data")
      }

      PUSH [TP,PORT2_IN_BTN]   (* PORT 2 of 5 *)
      {
        IF (!([TP,PORT2_IN_BTN]))
        {
          ON [TP,PORT2_IN_BTN]
          Port5Inputs = Port5Inputs | 2
        }
        ELSE
        {
          OFF[TP,PORT2_IN_BTN]
          Port5Inputs = Port5Inputs & ~2
        }
        ButtonPushed = PORT2_IN_BTN
        RW232data = Port5Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P5_SELECT, "RW232data")
      }

      PUSH [TP,PORT3_IN_BTN]   (* PORT 3 of 5 *)
      {
        IF (!([TP,PORT3_IN_BTN]))
        {
          ON [TP,PORT3_IN_BTN]
          Port5Inputs = Port5Inputs | 4
        }
        ELSE
        {
          OFF[TP,PORT3_IN_BTN]
          Port4Inputs = Port4Inputs & ~4
        }
        ButtonPushed = PORT3_IN_BTN
        RW232data = Port5Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P5_SELECT, "RW232data")
      }

      PUSH [TP,PORT4_IN_BTN]   (* PORT 4 of 5 *)
      {
        IF (!([TP,PORT4_IN_BTN]))
        {
          ON [TP,PORT4_IN_BTN]
          Port5Inputs = Port5Inputs | 8
        }
        ELSE
        {
          OFF[TP,PORT4_IN_BTN]
          Port5Inputs = Port5Inputs & ~8
        }
        ButtonPushed = PORT4_IN_BTN
        RW232data = Port5Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P5_SELECT, "RW232data")
      }

      PUSH [TP,PORT5_IN_BTN]   (* PORT 5 of 5 ECB 62 only *)
      {
        IF (!([TP,PORT5_IN_BTN]))
        {
          ON [TP,PORT5_IN_BTN]
          Port5Inputs = Port5Inputs | 32
        }
        ELSE
        {
          OFF[TP,PORT5_IN_BTN]
          Port5Inputs = Port5Inputs & ~32
        }
        ButtonPushed = PORT5_IN_BTN
        RW232data = Port5Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P5_SELECT, "RW232data")
      }

      PUSH [TP,PORT6_IN_BTN]   (* PORT 6 of 5 *)
      {
        IF (!([TP,PORT6_IN_BTN]))
        {
          ON [TP,PORT6_IN_BTN]
          Port5Inputs = Port5Inputs | 16
        }
        ELSE
        {
          OFF[TP,PORT6_IN_BTN]
          Port5Inputs = Port5Inputs & ~16
        }
        ButtonPushed = PORT6_IN_BTN
        RW232data = Port5Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P5_SELECT, "RW232data")
      }
    }    (* End Port 5 Input Select *)

    IF ([TP,PORT6_OUT_BTN])   (* Port 6 Input Select *)
    {
      PUSH [TP,PORT1_IN_BTN]   (* PORT 1 of 6 *)
      {
        IF (!([TP,PORT1_IN_BTN]))
        {
          ON [TP,PORT1_IN_BTN]
          Port6Inputs = Port6Inputs | 1
        }
        ELSE
        {
          OFF[TP,PORT1_IN_BTN]
          Port6Inputs = Port6Inputs & ~1
        }
        ButtonPushed = PORT1_IN_BTN
        RW232data = Port6Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P6_SELECT, "RW232data")
      }

      PUSH [TP,PORT2_IN_BTN]   (* PORT 2 of 6 *)
      {
        IF (!([TP,PORT2_IN_BTN]))
        {
          ON [TP,PORT2_IN_BTN]
          Port6Inputs = Port6Inputs | 2
        }
        ELSE
        {
          OFF[TP,PORT2_IN_BTN]
          Port6Inputs = Port6Inputs & ~2
        }
        ButtonPushed = PORT2_IN_BTN
        RW232data = Port6Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P6_SELECT, "RW232data")
      }

      PUSH [TP,PORT3_IN_BTN]   (* PORT 3 of 6 *)
      {
        IF (!([TP,PORT3_IN_BTN]))
        {
          ON [TP,PORT3_IN_BTN]
          Port6Inputs = Port6Inputs | 4
        }
        ELSE
        {
          OFF[TP,PORT3_IN_BTN]
          Port6Inputs = Port6Inputs & ~4
        }
        ButtonPushed = PORT3_IN_BTN
        RW232data = Port6Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P6_SELECT, "RW232data")
      }

      PUSH [TP,PORT4_IN_BTN]  (* PORT 4 of 6 *)
      {
        IF (!([TP,PORT4_IN_BTN]))
        {
          ON [TP,PORT4_IN_BTN]
          Port6Inputs = Port6Inputs | 8
        }
        ELSE
        {
          OFF[TP,PORT4_IN_BTN]
          Port6Inputs = Port6Inputs & ~8
        }
        ButtonPushed = PORT4_IN_BTN
        RW232data = Port6Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P6_SELECT, "RW232data")
      }

      PUSH [TP,PORT5_IN_BTN]  (* PORT 5 of 6 *)
      {
        IF (!([TP,PORT5_IN_BTN]))
        {
          ON [TP,PORT5_IN_BTN]
          Port6Inputs = Port6Inputs | 16
        }
        ELSE
        {
          OFF[TP,PORT5_IN_BTN]
          Port6Inputs = Port6Inputs & ~16
        }
        ButtonPushed = PORT5_IN_BTN
        RW232data = Port6Inputs
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_P6_SELECT, "RW232data")
      }
    }    (* End Port 6 Input Select *)
  }   (* End PORTS INPUT *)

(******************************  RPD PAGE ***********************************)
  PUSH [TP,REMOTE_DIAG_BTN]
  {
   IF(![TP,REMOTE_DIAG_BTN])
   {
     [TP,REMOTE_DIAG_BTN] = 1
     RW232data = 2           (* ANSWER ALWAYS *)
     ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
     SYSTEM_CALL 'RW232_Q' (RPD_1, RPD1_ADDRESS, RW232_SEND_DATA, 0, 0, RPD1_ANSWER_WHEN, "RW232data")
     RW232data = 0           (* ANSWER DATA *)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
     SYSTEM_CALL 'RW232_Q' (RPD_1, RPD1_ADDRESS, RW232_SEND_DATA, 0, 0, RPD1_ANSWER_MODE, "RW232data")
   }
   ELSE   (* Remote Diagnostics off - Disable Auto Answer*)
   {
     [TP,REMOTE_DIAG_BTN] = 0
     RW232data = 0           (* ANSWER NEVER *)
     ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
     SYSTEM_CALL 'RW232_Q' (RPD_1, RPD1_ADDRESS, RW232_SEND_DATA, 0, 0, RPD1_ANSWER_WHEN, "RW232data")
   }
 }

(******************************  ECM PAGE ***********************************)
  IF (![TP,REMOTE_DIAG_BTN])
  {
    IF (PUSH_DEVICE = TP)
    {
      KeyPressed = PUSH_CHANNEL

      IF (Element < 20)
      {
        IF (!OffHook)  (* Enter number and then press Dial *)
        {
          IF ((KeyPressed >= 47) && (KeyPressed <= 59))
          {
            IF (ClearOldNumber)             (* Start with new number *)
              CALL 'ClearKey'
            Element = Element + 1
            IF (KeyPressed <= 57)
              KeyPadEntry[Element] = KeyPressed
            IF (KeyPressed = 58)
              KeyPadEntry[Element] = '*'
            IF (KeyPressed = 59)
              KeyPadEntry[Element] = '#'
            IF (KeyPressed = PAUSE_FLASH_BTN)  (* 47 *)
              KeyPadEntry[Element] = ','
            SET_LENGTH_STRING (KeyPadEntry, Element)
            NewKey = 1
          }
        }
        ELSE  (* If in Off Hook allow for single key entry without changing last entry *)
        {
          IF ((KeyPressed >= 48) && (KeyPressed <= 59))
          {
            Selement = Selement + 1
            IF (KeyPressed <= 57)
              SingleKey[Selement] = KeyPressed
            IF (KeyPressed = 58)
              SingleKey[Selement] = '*'
            IF (KeyPressed = 59)
              SingleKey[Selement] = '#'
            SET_LENGTH_STRING (SingleKey, Selement)
            SEND_COMMAND TP,"'!F',2,KEY_FONT"
            SEND_COMMAND TP,"'!T',2,SingleKey"
                       (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
            SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD,
                                   0, 0, "SingleKey[Selement],0")
          }
        }
      }
    }

    PUSH [TP,BACKSPACE_BTN]
    {
      IF (Element)
      {
        Element = Element - 1
        SET_LENGTH_STRING (KeyPadEntry, Element)
        SEND_COMMAND TP,"'!T',2,KeyPadEntry"
        NewKey = 1
      }
    }

    PUSH [TP,CLEAR_BTN]
    {
      CALL 'ClearKey'
    }

    IF (OffHook) (* Allow for dialing during off hook *)
    {
      IF (KeyReady)
      {
        KeyReady = 0
        LastEntry = KeyPadEntry
                    (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
                    (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
        SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "KeyPadEntry,0")
      }
    }
    ELSE (* Not in call - Unit in On Hook state *)
    {
      PUSH [TP,ANSWER_DIAL_BTN]
      {
        PULSE [TP,ANSWER_DIAL_BTN]
        OffHook = 1
        IF (KeyReady)           (* If number entered dial number *)
        {
          KeyReady = 0
          LastEntry = KeyPadEntry
                    (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
                    (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
          SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "KeyPadEntry,0")
          ClearOldNumber = 1
        }
        ELSE (* Answer only *)
        {
                    (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = Off Hook *)
          SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_OFF_HOOK_CMD, 0, 0, "1")
        }
      }

      PUSH [TP,PHONE_REDIAL_BTN]
      {
        KeyPadEntry = LastEntry
        IF (LENGTH_STRING (KeyPadEntry))
        {
          NewKey = 1 (* display last number *)
          PULSE [TP,ANSWER_DIAL_BTN]
          OffHook = 1
                    (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
          SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "KeyPadEntry,0")
          ClearOldNumber = 1
        }
      }
    }

    PUSH [TP,HANG_UP_BTN]
    {
      CALL 'ClearKey'
      CALL 'ClearSingleKey'
      OffHook = 0
      PULSE [TP,HANG_UP_BTN]
      PULSE [TP,ANSWER_DIAL_BTN]
                    (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = On Hook *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_OFF_HOOK_CMD, 0, 0, "0")
    }

    PUSH [TP,PAUSE_FLASH_BTN]
    {
      IF (OffHook) (* Flash *)
      {
                    (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
        SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "!1,0")
      }
    }

    PUSH [TP,AUTO_ANSWER_BTN]
    {
      IF (![TP,AUTO_ANSWER_BTN])
      {
        ON [TP,AUTO_ANSWER_BTN]
        RW232data = 2        (* ANSWER on 2nd Ring *)
      }
      ELSE
      {
        OFF [TP,AUTO_ANSWER_BTN]
        RW232data = 0        (* Auto ANSWER off *)
      }
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_DATA, 0,  0, ECM64_AA_RING_COUNT, "RW232data")
    }

    PUSH [TP,AUTO_DISCONNECT_BTN]
    {
      IF (![TP,AUTO_DISCONNECT_BTN])
      {
        ON [TP,AUTO_DISCONNECT_BTN]
        RW232data = 1
      }
      ELSE
      {
        OFF [TP,AUTO_DISCONNECT_BTN]
        RW232data = 0
      }
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_DATA, 0,  0, ECM64_AUTO_DISCONNECT, "RW232data")
    }

    PUSH [TP,LOCATION1_BTN]
    {
      IF (!([TP,LOCATION1_BTN]))
      {
        IF (ProgramLocation)
        {
          OFF [TP,STORE_NUMBER_BTN]
          OFF [TP,LOCATION1_BTN]
          ProgramLocation = 0
          Location1Text = KeyPadEntry
          ClearOldNumber = 1
        }
        ELSE
        {
          ON [TP,LOCATION1_BTN]
          KeyPadEntry = Location1Text
          NewKey = 1
          ClearOldNumber = 1
        }
      }
    }

    PUSH [TP,LOCATION2_BTN]
    {
      IF (!([TP,LOCATION2_BTN]))
      {
        IF (ProgramLocation)
        {
          OFF [TP,STORE_NUMBER_BTN]
          OFF [TP,LOCATION2_BTN]
          ProgramLocation = 0
          Location2Text = KeyPadEntry
          ClearOldNumber = 1
        }
        ELSE
        {
          ON [TP,LOCATION2_BTN]
          KeyPadEntry = Location2Text
          NewKey = 1
          ClearOldNumber = 1
        }
      }
    }

    PUSH [TP,LOCATION3_BTN]
    {
      IF (!([TP,LOCATION3_BTN]))
      {
        IF (ProgramLocation)
        {
          OFF [TP,STORE_NUMBER_BTN]
          OFF [TP,LOCATION3_BTN]
          ProgramLocation = 0
          Location3Text = KeyPadEntry
          ClearOldNumber = 1
        }
        ELSE
        {
          ON [TP,LOCATION3_BTN]
          KeyPadEntry = Location3Text
          NewKey = 1
          ClearOldNumber = 1
        }
      }
    }

    PUSH [TP,LOCATION4_BTN]
    {
      IF (!([TP,LOCATION4_BTN]))
      {
        IF (ProgramLocation)
        {
          OFF [TP,STORE_NUMBER_BTN]
          OFF [TP,LOCATION4_BTN]
          ProgramLocation = 0
          Location4Text = KeyPadEntry
          ClearOldNumber = 1
        }
        ELSE
        {
          ON [TP,LOCATION4_BTN]
          KeyPadEntry = Location4Text
          NewKey = 1
          ClearOldNumber = 1
        }
      }
    }

    PUSH [TP,CLEAR_BTN]
    {
      CALL 'ClearKey'
    }

    IF (NewKey)
    {
      NewKey = 0
      KeyReady = 1
      SEND_COMMAND TP,"'!F',2,KEY_FONT"
      SEND_COMMAND TP,"'!T',2,KeyPadEntry"
    }

    IF (KeyReady)
    {
      PUSH [TP,STORE_NUMBER_BTN]
      {
        ON [TP,STORE_NUMBER_BTN]
        ProgramLocation = 1
        KeyReady = 0
      }
    }
  }  (* End Not Remote Diag *)



(******************************  RPM PAGE ***********************************)
  IF ([TP,RPM_SELECT_BTN])
  {
    PUSH[TP,MEM1_BTN]
    {
      ON [TP,MEM1_BTN]
      RPMmemory = MEM1_BTN
      ButtonPushed = MEM1_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPM_26, RPM26_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1, 0, "")
    }
    PUSH[TP,MEM2_BTN]
    {
      ON [TP,MEM2_BTN]
      RPMmemory = MEM2_BTN
      ButtonPushed = MEM2_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPM_26, RPM26_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY2, 0, "")
    }
    PUSH[TP,MEM3_BTN]
    {
      ON [TP,MEM3_BTN]
      RPMmemory = MEM3_BTN
      ButtonPushed = MEM3_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPM_26, RPM26_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY3, 0, "")
    }
    PUSH[TP,MEM4_BTN]
    {
      ON [TP,MEM4_BTN]
      RPMmemory = MEM4_BTN
      ButtonPushed = MEM4_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPM_26, RPM26_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY4, 0, "")
    }
  }
  IF ([TP,RPE_SELECT_BTN])
  {
    PUSH[TP,MEM1_BTN]
    {
      ON [TP,MEM1_BTN]
      RPEmemory = MEM1_BTN
      ButtonPushed = MEM1_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPE_228, RPE228_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1, 0, "")
    }
    PUSH[TP,MEM2_BTN]
    {
      ON [TP,MEM2_BTN]
      RPEmemory = MEM2_BTN
      ButtonPushed = MEM2_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPE_228, RPE228_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY2, 0, "")
    }
    PUSH[TP,MEM3_BTN]
    {
      ON [TP,MEM3_BTN]
      RPEmemory = MEM3_BTN
      ButtonPushed = MEM3_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPE_228, RPE228_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY3, 0, "")
    }
    PUSH[TP,MEM4_BTN]
    {
      ON [TP,MEM4_BTN]
      RPEmemory = MEM4_BTN
      ButtonPushed = MEM4_BTN
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RPE_228, RPE228_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY4, 0, "")
    }
  }
}  (* END SYSTEM READY *)

IF (SystemOn)
{
  SYSTEM_CALL 'DoRW232' (RW232) 
(* Device Device SR1, Set to 1 if using Axcess without DSC1, Set to 0 if using Netlinx *)
  SYSTEM_CALL 'DoSR1' (SR1,1) (* SR1 connected directly, no DSC1 or Netlinx *)
}


(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)
