PROGRAM_NAME='RwDemo2 - RaneWare Demo 2 Basic'
(*   DATE:08/29/01    TIME:14:39:48    *)
(**********************************************************************)
(* Rane Corp. By: Mike Slattery                                       *)
(* Basic Panja calls and routines that are required to                *)
(*  operate an ECB 62.                                                *)
(* Opstat data are not supported.                                     *)
(* This program also demonstrates the use of Memory Recalls, the      *)
(*  Chairman Mic and Mute functions.                                  *)
(* Set the ECB2 6 Address to 4                                        *)
(* Load RwDemo2.PGZ into the touch Panel                              *)
(* Include files: RaneCon.axi, RaneVar.axi                            *)
(* Library Files: RW232_Q.lib, DoRW232.lib, RaneIni.lib, Rw232Vols.lib   *)
(**********************************************************************)

(*!!!!!!!!!!! Variable RaneInfo can be used for diagnostics !!!!!!!!!!!!!*)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
RW232       = 1  (* AXC-SER RANE RW232 *)
                 (* BAUD 19200,E,8,1 485 DISABLED *)
TP          = 128

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(* RW 232 Device Addresses *)
ECB62_ADDRESS    = 4

(* Don't include if not used *)
INCLUDE_RW232   = 1   (* This Program uses RW232 *)
INCLUDE_ECB62   = 1   (* This Program uses the ECB 6 *)

INCLUDE 'RaneCon.axi'   (* Rane Constants - Contains all the SPLs -
                          Must be assigned last *)

(* Button Names *)

MEM1_BTN       = 11
MEM2_BTN       = 12
MEM3_BTN       = 13
MEM4_BTN       = 14
MIC_MEM1_BTN   = 15
MIC_MEM2_BTN   = 16
MIC_MEM3_BTN   = 17
PORT_MEM1_BTN  = 18
PORT_MEM2_BTN  = 19
PORT_MEM3_BTN  = 20
CHAIRMAN_BTN   = 21
MUTE_ALL       = 22
MUTE_PORT1     = 23
MUTE_PORT2     = 24
MUTE_PORT3     = 25
MUTE_PORT4     = 26
MUTE_PORT5     = 27
MUTE_PORT6     = 28

PGM_VOL_BAR     = 1
PGM_UP_BTN      = 2
PGM_DWN_BTN     = 3
PGM_MUTE_BTN    = 4

CLEAR_TP = 88

KEY_FONT         = '3'  (* Medium Font *)

SYSTEM_ON      = 100
SYSTEM_OFF     = 101


(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

INCLUDE 'RaneVar.axi'  (* Rane Variables *)

SystemOn

PGMvolume
OldPGMvolume
OldCPGMvol
NewVolume
ButtonPushed
RW232data

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       TOGGLING DEFINITIONS GO BELOW                     *)
(***********************************************************)
DEFINE_TOGGLING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE
([TP,SYSTEM_ON],[TP,SYSTEM_OFF])
([TP,MEM1_BTN]..[TP,PORT_MEM3_BTN])

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)


(*********** Clear System ****************)
(* Initializes system by clearing or setting all startup parameters *)
DEFINE_CALL 'ClearSystem'
{
  RaneInfo = "" (* Use this variable for system debug *)
  SYSTEM_CALL 'RaneIni'
  (* Used to clear the level ontrol *)
  SYSTEM_CALL 'Rw232Vols'(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255)
}

(*********** System Start ****************)
(* Initializes system by clearing or setting all startup parameters *)
DEFINE_CALL 'SystemStart'
{
  (* Power-up system *)
  (* ON[RELAY,POWER] *)

  ON [TP,SYSTEM_ON]
  CALL 'ClearSystem'
  SystemOn = 1
  SystemReady = 1
  (* Set Volume levels *)
  (* Recall Memory 1 on all units *)
              (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
  SYSTEM_CALL 'RW232_Q' (RW232_ALL_DEVICES, RW232_ALL_DEVICES, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1,0,"")
  OldPGMvolume        = 255
  OldCPGMvol          = 255

(* The TP Level will must be incremented to be changed.  *)
  PGMvolume = 191 (* 10 dB ECB = 255 - ((ECB62 Volume = 20) * 255) / 80)  see RW Manual-26 *)

  IF (PGMvolume)
  {
    SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume-1
    SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume
  }
}

(*********** System Off ****************)
DEFINE_CALL 'SystemOff'
{
  (* Power-Down system *)
  (* OFF[RELAY,POWER] *)

  ON [TP,SYSTEM_OFF]
  CALL 'ClearSystem'
  (* Recall Memory 1 on all units *)
              (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
  SYSTEM_CALL 'RW232_Q' (RW232_ALL_DEVICES, RW232_ALL_DEVICES, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1,0,"")
  SystemReady = 0
  WAIT 10
    SystemOn = 0
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

CREATE_LEVEL TP, PGM_VOL_BAR, PGMvolume
SEND_COMMAND TP,'PAGE-MAIN'

SEND_COMMAND RW232,'SET BAUD 19200,E,8,1 485 DISABLED'
CREATE_BUFFER RW232, RW232rxBuffer

WAIT 20
{
  CALL 'ClearSystem'
  SystemOn = 1
  SystemReady = 1
  CALL 'SystemOff'
}

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM


PUSH [TP,SYSTEM_ON]
  IF (!([TP,SYSTEM_ON]))
    CALL 'SystemStart'

(* System Off *)
PUSH [TP,SYSTEM_OFF]
  CALL 'SystemOff'


IF (SystemOn && SystemReady)
{
      (* Resets the last button pressed if bad data is returned *)
      (* Set ButtonPushed to 0 if you do not want it reset *)
  IF (BadRaneData)
  {
    BadRaneData = 0
    IF (ButtonPushed)
    {
      IF ([TP,ButtonPushed])
        OFF[TP,ButtonPushed]
      ELSE
        ON[TP,ButtonPushed]
    }
  }


 (* VOLUME Format *)   (* TP, Up Btn, Dwn Btn, Mute Btn, UnMute Btn, Device Type,
                          Device Address, SPL Index, Volume, OldVolume, OldCalVolume *)
                       (*  Set UnMute to 0 to use Mute as Toggle              *)
(****** ECB 62 Out 1's Volume Control *********)
  NewVolume = 1  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, PGM_UP_BTN, PGM_DWN_BTN, PGM_MUTE_BTN, 0, ECB_62, ECB62_ADDRESS,
                           ECB62_P1OUT_VOL, PGMvolume, OldPGMvolume, OldCPGMvol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume

  (* Recall Mic Settings Memory 1 *)
  PUSH[TP,MIC_MEM1_BTN]
  {
    ON[TP,MIC_MEM1_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, MIC_SETTINGS, MEMORY1, 0, "")
    ButtonPushed = MIC_MEM1_BTN
  }

  (* Recall Mic Settings Memory 2 *)
  PUSH[TP,MIC_MEM2_BTN]
  {
    ON[TP,MIC_MEM2_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, MIC_SETTINGS, MEMORY2, 0, "")
    ButtonPushed = MIC_MEM2_BTN
  }

  (* Recall Mic Settings Memory 3 *)
  PUSH[TP,MIC_MEM3_BTN]
  {
    ON[TP,MIC_MEM3_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, MIC_SETTINGS, MEMORY3, 0, "")
    ButtonPushed = MIC_MEM3_BTN
  }

  (* Recall Port Settings Memory 1 *)
  PUSH[TP,PORT_MEM1_BTN]
  {
    ON[TP,PORT_MEM1_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, PORT_SETTINGS, MEMORY1, 0, "")
    ButtonPushed = PORT_MEM1_BTN
  }

  (* Recall Port Settings Memory 1 *)
  PUSH[TP,PORT_MEM2_BTN]
  {
    ON[TP,PORT_MEM2_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, PORT_SETTINGS, MEMORY2, 0, "")
    ButtonPushed = PORT_MEM2_BTN
  }

  (* Recall Port Settings Memory 3 *)
  PUSH[TP,PORT_MEM3_BTN]
  {
    ON[TP,PORT_MEM3_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, PORT_SETTINGS, MEMORY3, 0, "")
    ButtonPushed = PORT_MEM3_BTN
  }

  (* This button recalls all settings for memory 4 *)
  PUSH[TP,MEM1_BTN]
  {
    ON[TP,MEM1_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1, 0, "")
    ButtonPushed = MEM1_BTN
  }

  PUSH[TP,MEM2_BTN]
  {
    ON[TP,MEM2_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY2, 0, "")
    ButtonPushed = MEM2_BTN
  }

  PUSH[TP,MEM3_BTN]
  {
    ON[TP,MEM3_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY3, 0, "")
    ButtonPushed = MEM3_BTN
  }

  PUSH[TP,MEM4_BTN]
  {
    ON[TP,MEM4_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY4, 0, "")
    ButtonPushed = MEM4_BTN
  }

  (* The following is a method for chairmain (Mic 1 is chairman) *)
  PUSH[TP,CHAIRMAN_BTN]
  {
    IF (!([TP,CHAIRMAN_BTN]))
    {
      RW232data = 1    (* Force On *)
      ON[TP,CHAIRMAN_BTN]
    }
    ELSE
    {
      RW232data = 2    (* Automatic *)
      OFF[TP,CHAIRMAN_BTN]
    }
    ButtonPushed = CHAIRMAN_BTN
    (* Force Mic 1 on = 121 *)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_MIC1_MODE, "RW232data")

    IF (RW232data = 1)
      RW232data = ECB62_CHAIRMAN_ON  (* Chairman Mode On *)
    Else
      RW232data = ECB62_CHAIRMAN_OFF (* Chairman Mode Off *)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_SEND_DATA, 0, 0, ECB62_CHAIRMAN, "RW232data")
  }

  PUSH[TP,MUTE_ALL] (*MUTE ALL DEVICES*)
  {                    (* Sends a Broadcast command by setting the *)
                       (* Address to 0. *)
    IF([TP,MUTE_ALL])
    {
      OFF[TP,MUTE_ALL]   (* UNMUTE *)
      ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RW232_ALL_DEVICES, RW232_ALL_DEVICES, RW232_UNMUTE_DEVICE, 0, 0, 0, "")
    }
    ELSE
    {
      ON[TP,MUTE_ALL]   (* MUTE *)
      ButtonPushed = 0
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (RW232_ALL_DEVICES, RW232_ALL_DEVICES, RW232_MUTE_DEVICE, 0, 0, 0, "")
    }
  }

  IF(!([TP,MUTE_ALL]))
  {
    PUSH[TP,MUTE_PORT1] (*MUTE PORT 1*)
    {
      IF([TP,MUTE_PORT1])
      {
        OFF[TP,MUTE_PORT1]   (* UNMUTE *)
        ButtonPushed = MUTE_PORT1
                  (* Device Type, Device Address, Command, Channel - Port 1 = 0 *)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_UNMUTE_DEVICE, 0, 0, 0, "")
      }
      ELSE
      {
        ON[TP,MUTE_PORT1]   (* MUTE *)
        ButtonPushed = MUTE_PORT1
                  (* Device Type, Device Address, Command, Channel - Port 1 = 0 *)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_MUTE_DEVICE, 0, 0, 0, "")
      }
    }

    PUSH[TP,MUTE_PORT2] (*MUTE PORT 2*)
    {
      IF([TP,MUTE_PORT2])
      {
        OFF[TP,MUTE_PORT2]   (* UNMUTE *)
        ButtonPushed = MUTE_PORT2
                  (* Device Type, Device Address, Command, Channel - Port 2 = 1 *)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_UNMUTE_DEVICE, 1, 0, 0, "")
      }
      ELSE
      {
        ON[TP,MUTE_PORT2]   (* MUTE *)
        ButtonPushed = MUTE_PORT2
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_MUTE_DEVICE, 1, 0, 0, "")
      }
    }

    PUSH[TP,MUTE_PORT3] (*MUTE PORT 3*)
    {
      IF([TP,MUTE_PORT3])
      {
        OFF[TP,MUTE_PORT3]   (* UNMUTE *)
        ButtonPushed = MUTE_PORT3
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_UNMUTE_DEVICE, 2, 0, 0, "")
      }
      ELSE
      {
        ON[TP,MUTE_PORT3]   (* MUTE *)
        ButtonPushed = MUTE_PORT3
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_MUTE_DEVICE, 2, 0, 0, "")
      }
    }

    PUSH[TP,MUTE_PORT4] (*MUTE PORT 4*)
    {
      IF([TP,MUTE_PORT4])
      {
        OFF[TP,MUTE_PORT4]   (* UNMUTE *)
        ButtonPushed = MUTE_PORT4
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_UNMUTE_DEVICE, 3, 0, 0, "")
      }
      ELSE
      {
        ON[TP,MUTE_PORT4]   (* MUTE *)
        ButtonPushed = MUTE_PORT4
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_MUTE_DEVICE, 3, 0, 0, "")
      }
    }

    PUSH[TP,MUTE_PORT5] (*MUTE PORT 5*)
    {
      IF([TP,MUTE_PORT5])
      {
        OFF[TP,MUTE_PORT5]   (* UNMUTE *)
        ButtonPushed = MUTE_PORT5
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_UNMUTE_DEVICE, 4, 0, 0, "")
      }
      ELSE
      {
        ON[TP,MUTE_PORT5]   (* MUTE *)
        ButtonPushed = MUTE_PORT5
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_MUTE_DEVICE, 4, 0, 0, "")
      }
    }

    PUSH[TP,MUTE_PORT6] (*MUTE PORT 6*)
    {
      IF([TP,MUTE_PORT6])
      {
        OFF[TP,MUTE_PORT6]   (* UNMUTE *)
        ButtonPushed = MUTE_PORT6
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_UNMUTE_DEVICE, 5, 0, 0, "")
      }
      ELSE
      {
        ON[TP,MUTE_PORT6]   (* MUTE *)
        ButtonPushed = MUTE_PORT6
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
        SYSTEM_CALL 'RW232_Q' (ECB_62, ECB62_ADDRESS, RW232_MUTE_DEVICE, 5, 0, 0, "")
      }
    }
  }
}  (* END SYSTEM READY *)

IF (SystemOn)
{
  SYSTEM_CALL 'DoRW232' (RW232) 
}

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)



