PROGRAM_NAME='RwDemo3 - ECM 64 Demo'
(*   DATE:08/29/01    TIME:19:08:05    *)
(* Rane Corp. By: Mike Slattery                                          *)
(* This program demonstrates the ability of Panja to control the ECM 64  *)
(* Set the ECM 64 to address 1                                           *)
(*                                                                       *)
(* Include files: RaneCon.axi, RaneVar.axi                               *)
(* Library Files: RW232_Q.lib, DoRW232.lib, RaneIni.lib                  *)
(*                Rw232Vols.lib                                             *)
(*!!!!!!!!!!! Variable RaneInfo can be used for diagnostics !!!!!!!!!!!!!*)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
RW232       = 1  (* AXC-SER RANE RW232 *)
                 (* BAUD 19200,E,8,1 485 DISABLED *)
TP          = 128

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

     (* Opstats are used to get Hybrid status, like  Off Hook and Ring *)
(* !!!!! Don't include (INCLUDE_<UNIT>) if not used -
         Comment out or remove (INCLUDE_<UNIT>) !!!!! *)
INCLUDE_RW232         = 1   (* This Program uses RW232 *)
INCLUDE_ECM64         = 1   (* This Program uses the ECM 64 *)
INCLUDE_OPSTATS       = 1   (* This Program uses Opstats *)
INCLUDE_ECM64_OPSTATS = 1   (* This Program uses ECM OPSTATS *)
  (* RaneCon.axi must be after the above Includes *)
INCLUDE 'RaneCon.axi'   (* RW232 Constants - This file is worth printing out *)
                        (* Contains all the SPLs - See ECM 64 Manual page 16 *)
                        (* Must be located in the same directory as the .axs file*)

(* RW 232 Device Addresses *)
(*    DEVICE NAME: ECM 64                             *)
(* CONTROL METHOD: RS232                              *)
(*   MANUFACTURER: Rane                               *)
(*          MODEL: ECM64                              *)
(*  CONFIGURATION: 19200,8,E,1                        *)
ECM64_ADDRESS    = 5

(******** Button Names ***********)
MIC1_VOL_BAR     = 1
MIC2_VOL_BAR     = 2
MIC3_VOL_BAR     = 3
MIC4_VOL_BAR     = 4
LINE_IN_VOL_BAR  = 5
AUX_IN_VOL_BAR   = 6
PGM_VOL_BAR      = 7

MIC1_UP_BTN      = 1
MIC1_DWN_BTN     = 2
MIC1_MUTE_BTN    = 3
MIC2_UP_BTN      = 4
MIC2_DWN_BTN     = 5
MIC2_MUTE_BTN    = 6
MIC3_UP_BTN      = 7
MIC3_DWN_BTN     = 8
MIC3_MUTE_BTN    = 9
MIC4_UP_BTN      = 10
MIC4_DWN_BTN     = 11
MIC4_MUTE_BTN    = 12
LINE_IN_UP_BTN   = 13
LINE_IN_DWN_BTN  = 14
LINE_IN_MUTE_BTN = 15
AUX_IN_UP_BTN    = 16
AUX_IN_DWN_BTN   = 17
AUX_IN_MUTE_BTN  = 18
PGM_UP_BTN       = 19
PGM_DWN_BTN      = 20
PGM_MUTE_BTN     = 21

MEMORY1A_BTN        = 22
MEMORY2I_BTN        = 23
MEMORY2O_BTN        = 24
PHONE_HOOK_BTN      = 25
VOLUME_BARS         = 26
RING_LED            = 27

PHONE_DIAL_ANSWER_BTN = 30
PHONE_HANGUP_BTN      = 31
PHONE_REDIAL_BTN      = 32
PHONE_PAUSE_BTN       = 33
PHONE_FLASH_BTN       = 34
PHONE_AUTO_ANSWER_BTN = 35
PHONE_HOLD_BTN        = 36
PHONE_BACKSPACE_BTN   = 37
PHONE_CLEAR_BTN       = 38

SYSTEM_ON_BTN    = 101
SYSTEM_OFF_BTN   = 102

(************* END Button Names **************)
KEY_FONT         = '3'  (* Medium Font *)


(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

INCLUDE 'RaneVar.axi'  (* RW232 Variables used in the system calls - *)
                       (* Must be used and located in the same*)
                       (* directory as the .axs file *)
PGMvolume
OldPGMvolume
OldCPGMvol

Mic1Volume
OldMic1Volume
OldCMic1Vol

Mic2Volume
OldMic2Volume
OldCMic2Vol

Mic3Volume
OldMic3Volume
OldCMic3Vol

Mic4Volume
OldMic4Volume
OldCMic4Vol

LineInVolume
OldLineInVolume
OldCLineInVol

AuxInVolume
OldAuxInVolume
OldCAuxInVol

NewVolume
StopOpstat
SystemOn
ClearOldNumber

KeyPadEntry[20]
LastEntry[20]
SingleKey[20]
KeyPressed
Element
Selement
NewKey
KeyReady
OffHook
Rw232data

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       TOGGLING DEFINITIONS GO BELOW                     *)
(***********************************************************)
DEFINE_TOGGLING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE
([TP,MEMORY1A_BTN]..[TP,MEMORY2O_BTN])
([TP,SYSTEM_ON_BTN],[TP,SYSTEM_OFF_BTN])

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)


(***************** Clear SingleKey ****************)
DEFINE_CALL 'ClearSingleKey'
{
  KeyReady = 0
  Selement = 0
  SET_LENGTH_STRING (SingleKey,0)
  SEND_COMMAND TP,'TEXT2-|'
}

(***************** Clear Key ****************)
DEFINE_CALL 'ClearKey'
{
  SEND_COMMAND TP,'TEXT2-|'
  KeyReady = 0
  Element = 0
  SET_LENGTH_STRING (KeyPadEntry,0)
  ClearOldNumber = 0
}

(*********** Clear System ****************)
(* Initializes system by clearing or setting all startup parameters *)
DEFINE_CALL 'ClearSystem'
{
  RaneInfo = "" (* Use this variable for system debug *)
  SYSTEM_CALL 'RaneIni'
  CALL 'ClearKey'
  CALL 'ClearSingleKey'
  (* Used to clear the level ontrol *)
  SYSTEM_CALL 'Rw232Vols'(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255)

  OFF [TP,PHONE_AUTO_ANSWER_BTN]
  OFF [TP,PGM_MUTE_BTN]
  OFF [TP,MIC1_MUTE_BTN]
  OFF [TP,MIC2_MUTE_BTN]
  OFF [TP,MIC3_MUTE_BTN]
  OFF [TP,MIC4_MUTE_BTN]
  OFF [TP,LINE_IN_MUTE_BTN]
  OFF [TP,AUX_IN_MUTE_BTN]
  OFF [TP,MEMORY1A_BTN]
  OFF [TP,MEMORY2I_BTN]
  OFF [TP,MEMORY2O_BTN]
}

(*********** System Start ****************)
DEFINE_CALL 'SystemStart'
{
  (* Power-up system *)
  (* ON[RELAY,POWER] *)

  (* Reset volume level. TP only *)
  (* Since volume is within SystemReady and not in mainline, *)
  (* the TP Level will not jump it must be incremented.  *)

  CALL 'ClearSystem'
  OffHook    = 0
  StopOpstat = 0
  SystemOn = 1
  SystemReady = 1

  PGMvolume      = 196 (* Reset PGMvolume to -10dB out* = ((ECMlevel-58) * 255)/60 [ECMlevel = 118-4-10 = 104] *)
  Mic1Volume     = 128 (* Reset Mic1Volume to 0dB out*)
  Mic2Volume     = 128 (* Reset Mic2Volume to 0dB out*)
  Mic3Volume     = 128 (* Reset Mic3Volume to 0dB out*)
  Mic4Volume     = 128 (* Reset Mic4Volume to 0dB out*)
  LineInVolume   = 128 (* Reset LineinVolume to 0dB out*)
  AuxInVolume    = 128 (* Reset AuxInVolume to 0dB out*)
  (* Force Change in Level for display *)
  SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume-1
  SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume
  SEND_LEVEL TP,MIC1_VOL_BAR,Mic1Volume-1
  SEND_LEVEL TP,MIC1_VOL_BAR,Mic1Volume
  SEND_LEVEL TP,MIC2_VOL_BAR,Mic2Volume-1
  SEND_LEVEL TP,MIC2_VOL_BAR,Mic2Volume
  SEND_LEVEL TP,MIC3_VOL_BAR,Mic3Volume-1
  SEND_LEVEL TP,MIC3_VOL_BAR,Mic3Volume
  SEND_LEVEL TP,MIC4_VOL_BAR,Mic4Volume-1
  SEND_LEVEL TP,MIC4_VOL_BAR,Mic4Volume
  SEND_LEVEL TP,LINE_IN_VOL_BAR,LineInVolume-1
  SEND_LEVEL TP,LINE_IN_VOL_BAR,LineInVolume
  SEND_LEVEL TP,AUX_IN_VOL_BAR,AuxInVolume-1
  SEND_LEVEL TP,AUX_IN_VOL_BAR,AuxInVolume

  ON [TP,SYSTEM_ON_BTN]
  (* Recall Memory 2 All Memory to reset ECM 64 *)
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
  SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY2, 0, "")

}

(*********** System Off ****************)
DEFINE_CALL 'SystemOff'
{
  (* Power-Down system *)
  (* OFF[RELAY,POWER] *)

  SEND_COMMAND TP,"'@PPA'"  (* Clear all Popups *)

  ON [TP,SYSTEM_OFF_BTN]
  (* Recall Memory 1 to reset ECM 64 *)
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
  SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1, 0, "")
  SystemReady = 0
  WAIT 10
  {
    CALL 'ClearSystem'
    SystemOn = 0
  }
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

CREATE_LEVEL TP, PGM_VOL_BAR, PGMvolume
CREATE_LEVEL TP, MIC1_VOL_BAR, Mic1Volume
CREATE_LEVEL TP, MIC2_VOL_BAR, Mic2Volume
CREATE_LEVEL TP, MIC3_VOL_BAR, Mic3Volume
CREATE_LEVEL TP, MIC4_VOL_BAR, Mic4Volume
CREATE_LEVEL TP, LINE_IN_VOL_BAR, LineInVolume
CREATE_LEVEL TP, AUX_IN_VOL_BAR, AuxInVolume

SEND_COMMAND RW232, 'SET BAUD 19200, E, 8, 1, 485 DISABLE'
CREATE_BUFFER RW232, RW232rxBuffer

WAIT 20
{
  CALL 'ClearSystem'
  SystemOn = 1
  SystemReady = 1
  CALL 'SystemOff'
}

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(* System On *)
PUSH [TP,SYSTEM_ON_BTN]
  IF (!([TP,SYSTEM_ON_BTN]))
    CALL 'SystemStart'

(* System Off *)
PUSH [TP,SYSTEM_OFF_BTN]
  CALL 'SystemOff'

IF (SystemOn && SystemReady)
{
(**************** Get OPSTATs ************************)
  IF (NewVolume)     (* Stop Get Opstat *)
  {
    StopOpstat = 2
  }

  IF (StopOpstat)
    WAIT 10
      StopOpstat = StopOpstat - 1

  (* StopOpstat = 1 *)
  IF (!StopOpstat)
  {

    WAIT 10  (* 1 Sec *)
    {
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_GET_OPSTAT, 0, 0,  0, "")
    }
  }

(**************** ECM OPSTAT ************************)

  IF (ECM64opstatReady)
  {
    ECM64opstatReady = 0
    OffHook = RW232myData[7]
    [TP,PHONE_HOOK_BTN] = OffHook
    IF (RW232myData[8])
    {
      SEND_COMMAND TP,'ABEEP'
      PULSE [TP,RING_LED]
      SEND_COMMAND TP,"'@PPN-Audio Conf'"
    }
  }
(*********** End Opstats *************)



 (* VOLUME Format *)   (* TP, Up Btn, Dwn Btn, Mute Btn, UnMute Btn, Device Type, SPL Index,
                          Volume, OldVolume, OldCalVolume *)
                       (*  Set UnMute to 0 to use Mute as Toggle              *)

(****** ECM 64 Mic 1's Volume Control *********)
  NewVolume = 1  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, MIC1_UP_BTN, MIC1_DWN_BTN, MIC1_MUTE_BTN, 0, ECM_64, ECM64_ADDRESS,
                              ECM64_MIC1_LEVEL, Mic1Volume, OldMic1Volume, OldCMic1Vol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,MIC1_VOL_BAR,Mic1Volume

(****** ECM 64 Mic 2's Volume Control *********)
  NewVolume = 2  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, MIC2_UP_BTN, MIC2_DWN_BTN, MIC2_MUTE_BTN, 0, ECM_64, ECM64_ADDRESS,
                           ECM64_MIC2_LEVEL, Mic2Volume, OldMic2Volume, OldCMic2Vol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,MIC2_VOL_BAR,Mic2Volume

(****** ECM 64 Mic 3's Volume Control *********)
  NewVolume = 3  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, MIC3_UP_BTN, MIC3_DWN_BTN, MIC3_MUTE_BTN, 0, ECM_64, ECM64_ADDRESS,
                           ECM64_MIC3_LEVEL, Mic3Volume, OldMic3Volume, OldCMic3Vol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,MIC3_VOL_BAR,Mic3Volume

(****** ECM 64 Mic 4's Volume Control *********)
  NewVolume = 4  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, MIC4_UP_BTN, MIC4_DWN_BTN, MIC4_MUTE_BTN, 0, ECM_64, ECM64_ADDRESS,
                           ECM64_MIC4_LEVEL, Mic4Volume, OldMic4Volume, OldCMic4Vol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,MIC4_VOL_BAR,Mic4Volume

(****** ECM 64 Line In's Volume Control *********)
  NewVolume = 5  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, LINE_IN_UP_BTN, LINE_IN_DWN_BTN, LINE_IN_MUTE_BTN, 0, ECM_64, ECM64_ADDRESS,
                           ECM64_LINE_IN_LEVEL, LineInVolume, OldLineInVolume, OldCLineInVol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,LINE_IN_VOL_BAR,LineInVolume

(****** ECM 64 Auxm In's Volume Control *********)
  NewVolume = 6  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, AUX_IN_UP_BTN, AUX_IN_DWN_BTN, AUX_IN_MUTE_BTN, 0, ECM_64, ECM64_ADDRESS,
                           ECM64_AUX_IN_LEVEL, AuxInVolume, OldAuxInVolume, OldCAuxInVol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,AUX_IN_VOL_BAR,AuxInVolume

(****** ECM 64 Out 1's Volume Control *********)
  NewVolume = 7  (* Use NewVolume for both the volume # and if level has changed *)
  SYSTEM_CALL 'Rw232Vols'(TP, PGM_UP_BTN, PGM_DWN_BTN, PGM_MUTE_BTN, 0, ECM_64, ECM64_ADDRESS,
                           ECM64_OUT1_LEVEL, PGMvolume, OldPGMvolume, OldCPGMvol, NewVolume)
  IF (NewVolume)
    SEND_LEVEL TP,PGM_VOL_BAR,PGMvolume
(****************************************************************************)

  (* Recall Port Settings Memory 1 *)
  PUSH[TP,MEMORY1A_BTN]
  {
    ON[TP,MEMORY1A_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_RECALL_MEMORY, ALL_MEMORY, MEMORY1, 0, "")
  }

  PUSH[TP,MEMORY2I_BTN]
  {
    ON[TP,MEMORY2I_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_RECALL_MEMORY, INPUT_SETTINGS, MEMORY2, 0, "")
  }

  PUSH[TP,MEMORY2O_BTN]
  {
    ON[TP,MEMORY2O_BTN]
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_RECALL_MEMORY, OUTPUT_SETTINGS, MEMORY2, 0, "")
  }

                      (* RANE ECM 64 TELCO CONTROL *)

(******************************  ECM PAGE ***********************************)
  IF (PUSH_DEVICE = TP)
  {
    KeyPressed = PUSH_CHANNEL

    IF (Element < 20)
    {
      IF (!OffHook)  (* Enter number and then press Dial *)
      {
        IF ((KeyPressed >= 47) && (KeyPressed <= 59))
        {
          IF (ClearOldNumber)             (* Start with new number *)
            CALL 'ClearKey'
          Element = Element + 1
          IF (KeyPressed <= 57)
            KeyPadEntry[Element] = KeyPressed
          IF (KeyPressed = 58)
            KeyPadEntry[Element] = '*'
          IF (KeyPressed = 59)
            KeyPadEntry[Element] = '#'
          IF (KeyPressed = PHONE_PAUSE_BTN)  (* 47 *)
            KeyPadEntry[Element] = ','
          SET_LENGTH_STRING (KeyPadEntry, Element)
          NewKey = 1
        }
      }
      ELSE  (* If in Off Hook allow for single key entry without changing last entry *)
      {
        IF ((KeyPressed >= 48) && (KeyPressed <= 59))
        {
          Selement = Selement + 1
          IF (KeyPressed <= 57)
            SingleKey[Selement] = KeyPressed
          IF (KeyPressed = 58)
            SingleKey[Selement] = '*'
          IF (KeyPressed = 59)
            SingleKey[Selement] = '#'
          SET_LENGTH_STRING (SingleKey, Selement)
          SEND_COMMAND TP,"'!F',2,KEY_FONT"
          SEND_COMMAND TP,"'!T',2,SingleKey"
                     (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
          SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD,
                                 0, 0, "SingleKey[Selement],0")
        }
      }
    }
  }

  PUSH [TP,PHONE_BACKSPACE_BTN]
  {
    TO[TP,PHONE_BACKSPACE_BTN]
    IF (Element)
    {
      Element = Element - 1
      SET_LENGTH_STRING (KeyPadEntry, Element)
      SEND_COMMAND TP,"'!T',2,KeyPadEntry"
      NewKey = 1
    }
  }

  PUSH [TP,PHONE_CLEAR_BTN]
  {
    TO[TP,PHONE_CLEAR_BTN]
    CALL 'ClearKey'
  }

  IF (NewKey)
  {
    NewKey = 0
    KeyReady = 1
    SEND_COMMAND TP,"'!F',2,KEY_FONT"
    SEND_COMMAND TP,"'!T',2,KeyPadEntry"
  }

  IF (OffHook) (* Allow for dialing during off hook *)
  {
    IF (KeyReady)
    {
      KeyReady = 0
      LastEntry = KeyPadEntry
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "KeyPadEntry,0")
    }
  }
  ELSE (* Not in call - Unit in On Hook state *)
  {
    PUSH [TP,PHONE_DIAL_ANSWER_BTN]
    {
      PULSE [TP,PHONE_DIAL_ANSWER_BTN]
      IF (KeyReady)           (* If number entered dial number *)
      {
        KeyReady = 0
        LastEntry = KeyPadEntry
                  (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
        SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "KeyPadEntry,0")
        ClearOldNumber = 1
      }
      ELSE (* Answer only *)
      {
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = Off Hook *)
        SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_OFF_HOOK_CMD, 0, 0, "1")
      }
    }

    PUSH [TP,PHONE_REDIAL_BTN]
    {
      PULSE [TP,PHONE_REDIAL_BTN]
      KeyPadEntry = LastEntry
      IF (LENGTH_STRING (KeyPadEntry))
      {
        NewKey = 1 (* display last number *)
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
        SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "KeyPadEntry,0")
        ClearOldNumber = 1
      }
    }
  }

  PUSH [TP,PHONE_HANGUP_BTN]
  {
    CALL 'ClearKey'
    CALL 'ClearSingleKey'
    PULSE [TP,PHONE_HANGUP_BTN]
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = On Hook *)
    SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_OFF_HOOK_CMD, 0, 0, "0")
  }

  PUSH [TP,PHONE_HOOK_BTN]
  {
    IF (OffHook)
    {
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = On Hook *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_OFF_HOOK_CMD, 0, 0, "0")
    }
    ELSE
    {
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = On Hook *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_OFF_HOOK_CMD, 0, 0, "1")
    }
  }

  PUSH [TP,PHONE_FLASH_BTN]
  {
    IF (OffHook) (* Flash *)
    {
                  (* Device Type, Device Address, Command, Hybrid Command, 0,0, Data = number, NULL *)
      SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_HYBRID_CMD, ECM64_DIAL_CMD, 0, 0, "!1,0")
    }
  }

  PUSH [TP,PHONE_AUTO_ANSWER_BTN]
  {
    IF (![TP,PHONE_AUTO_ANSWER_BTN])
    {
      ON [TP,PHONE_AUTO_ANSWER_BTN]
      RW232data = 2        (* ANSWER on 2nd Ring *)
    }
    ELSE
    {
      OFF [TP,PHONE_AUTO_ANSWER_BTN]
      RW232data = 0        (* Auto ANSWER off *)
    }
                (* Device Type, Device Address, Command, Channel, Memory, Starting SPL, "Data" *)
    SYSTEM_CALL 'RW232_Q' (ECM_64, ECM64_ADDRESS, RW232_SEND_DATA, 0,  0, ECM64_AA_RING_COUNT, "RW232data")
  }
} (* END SYSTEM READY *)

IF (SystemOn)
{
  SYSTEM_CALL 'DoRW232' (RW232) 
}

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)



