PROGRAM_NAME='SR3-SRM66 Demo2 - Rane'
(*   DATE:10/23/01    TIME:16:10:25    *)
(* Rane Corp. By: Mike Slattery                            *)
(* This Demo Program allows the Rane SR 3 to control the   *)
(* Rane SRM 66. There are foures: MUTE, BAR, LOBBY & POOL  *)
(* When a page is selected, the current source is          *)
(* displayed. For 4 seconds you can select four sources    *)
(* using the encoder knob: CD, DVD, DJ, Mute. Once a source*)
(* is selected, press the encoder knob to route the source.*)
(* The encoder control on the SR 3 operates the SRM 66     *)
(* Group Level for the selected Room.                      *)
(* System powers up with Mute Page and all Group Levels    *)
(* are set to 15 (mid position).                           *)
(* Include files: RaneCon.axi, RaneVar.axi                 *)
(* Library Files: SRM_Q.lib, RW485_Q.lib, RaneIni.lib,     *)
(*                DoSRM.lib, GroupSR1.lib, DoSR3.lib       *)
(* RW485_Q (INTEGER DevAddr, INTEGER DevType, Cmd[10], Msg[40]) *)
(***********************************************************)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
SRM         = 1          (* RANE SRM 9600,N,8,1,485 ENABLE *)
SR3         = 2          (* RANE SR3 38400,N,8,1,485 ENABLE*)
(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(* Do not include if not used - either comment out or delete *)
INCLUDE_RW485  = 1   (* This Program uses RW485  *)
INCLUDE_SR3    = 1   (* This Program uses SR 3s  *)
INCLUDE_SRM66  = 1   (* This Program uses SRM 66 *)
  (* Must be after the Includes *)
INCLUDE 'RaneCon.axi'   (* Rane Constants *)

(* The following sets the SRM 66 Vols *)
UNMUTE_CD      = 6  (* 0 = +6dB, 6 = 0dB *)
UNMUTE_DVD     = 6  (* 0 = +6dB, 6 = 0dB *)
UNMUTE_DJ      = 6  (* 0 = +6dB, 6 = 0dB *)
OUT_MASTER     = 35 (* 25-35 = -10dB Where 25 = 0dB*)

CD   = 1
DVD  = 2
DJ   = 3
MUTE = 4

MUTE_PAGE  = 1
BAR_PAGE   = 2
LOBBY_PAGE = 3
POOL_PAGE  = 4

SR3_LEFT  = 1
SR3_RIGHT = 2
SR3_ENTER = 64

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

INCLUDE 'RaneVar.axi'  (* Rane Variables *)
BarVol
LobbyVol
PoolVol
SystemOn
Group
SRMlevel
OldLevel
SelectTimer
PageSource[4]
NewPs
LedOff

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       TOGGLING DEFINITIONS GO BELOW                     *)
(***********************************************************)
DEFINE_TOGGLING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)

DEFINE_CALL 'EnterDevice'
{
  SELECT
  {
    ACTIVE (SR3page[2] = BAR_PAGE): (* Page 1 Selected *)
    {
      SR3level[2] = BarVol
      Group = 1
      SELECT
      {
        ACTIVE (NewPs = CD):
        {
          (* Select CD for Lobby and and Mute all other Vols *)
                                      (* Out 3 Lobby L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"UNMUTE_CD,32,32,32,32,32,OUT_MASTER,28,
                           (*Out 4 Lobby R *)  32,UNMUTE_CD,32,32,32,32")
        }
        ACTIVE (NewPs = DVD):
        {
          (* Select DVD for Lobby and and Mute all other Vols *)
                                      (* Out 3 Lobby L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"32,32,UNMUTE_DVD,32,32,32,OUT_MASTER,28,
                          (* Out 4 Lobby R *)  32,32,32,UNMUTE_DVD,32,32")
        }
        ACTIVE (NewPs = DJ):
        {
          (* Select DJ for Lobby and and Mute all other Vols *)
                                      (* Out 3 Lobby L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"32,32,32,32,UNMUTE_DJ,32,OUT_MASTER,28,
                          (* Out 4 Lobby R *)  32,32,32,32,32,UNMUTE_DJ")
        }
        ACTIVE (NewPs = MUTE):
        {
          (* Select MUTE all for Lobby *)
                              (* Out 1 Bar L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"32,32,32,32,32,32,OUT_MASTER,28,
                             (* Out 4 Lobby R *)  32,32,32,32,32,32")
        }
      }
    }
    ACTIVE (SR3page[2] = LOBBY_PAGE): (* Page 2 Selected *)
    {
      SR3level[2] = LobbyVol
      Group = 2
      SELECT
      {
        ACTIVE (NewPs = CD):
        {
          (* Select CD for Lobby and and Mute all other Vols *)
                                      (* Out 3 Lobby L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"UNMUTE_CD,32,32,32,32,32,OUT_MASTER,28,
                           (*Out 4 Lobby R *)  32,UNMUTE_CD,32,32,32,32")
        }
        ACTIVE (NewPs = DVD):
        {
          (* Select DVD for Lobby and and Mute all other Vols *)
                                      (* Out 3 Lobby L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"32,32,UNMUTE_DVD,32,32,32,OUT_MASTER,28,
                          (* Out 4 Lobby R *)  32,32,32,UNMUTE_DVD,32,32")
        }
        ACTIVE (NewPs = DJ):
        {
          (* Select DJ for Lobby and and Mute all other Vols *)
                                      (* Out 3 Lobby L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"32,32,32,32,UNMUTE_DJ,32,OUT_MASTER,28,
                          (* Out 4 Lobby R *)  32,32,32,32,32,UNMUTE_DJ")
        }
        ACTIVE (NewPs = MUTE):
        {
          (* Select MUTE all for Lobby *)
                              (* Out 1 Bar L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,16,"32,32,32,32,32,32,OUT_MASTER,28,
                             (* Out 4 Lobby R *)  32,32,32,32,32,32")
        }
      }
    }
    ACTIVE (SR3page[2] = POOL_PAGE): (* Page 3 Selected *)
    {
      SR3level[2] = PoolVol
      Group = 3
      SELECT
      {
        ACTIVE (NewPs = CD):
        {
          (* Select CD for Pool and and Mute all other Vols *)
                               (* Out 5 Pool L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,32,"UNMUTE_CD,32,32,32,32,32,OUT_MASTER,28,
                           (* Out 6 Pool R *)  32,UNMUTE_CD,32,32,32,32")
        }
        ACTIVE (NewPs = DVD):
        {
          (* Select DVD for Pool and and Mute all other Vols *)
                               (* Out 5 Pool L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,32,"32,32,UNMUTE_DVD,32,32,32,OUT_MASTER,28,
                           (* Out 6 Pool R *)  32,32,32,UNMUTE_DVD,32,32")
        }
        ACTIVE (NewPs = DJ):
        {
          (* Select DJ for Pool and and Mute all other Vols *)
                               (* Out 5 Pool L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,32,"32,32,32,32,UNMUTE_DJ,32,OUT_MASTER,28,
                           (* Out 6 Pool R *)  32,32,32,32,32,UNMUTE_DJ")
        }
        ACTIVE (NewPs = MUTE):
        {
          (* Select MUTE all for Pool *)
                              (* Out 1 Bar L - IN1,IN2,IN3,IN4,IN5,IN6 *)
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,32,"32,32,32,32,32,32,OUT_MASTER,28,
                              (* Out 6 Pool R *)  32,32,32,32,32,32")
        }
      }
    }
  }
}

DEFINE_CALL 'Display Source' (Ps,Pg)
{
  SYSTEM_CALL 'RW485_Q' (1,SR_3,'PS',"ITOA(Pg)") (* Use to clear text *)
  SELECT
  {
    ACTIVE (Ps = CD):
    {
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'SC','2,"CD"') (* Must have " " around string *)
    }
    ACTIVE (Ps = DVD):
    {
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'SC','2,"DVD"') (* Must have " " around string *)
    }
    ACTIVE (Ps = DJ):
    {
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'SC','2,"DJ"') (* Must have " " around string *)
    }
    ACTIVE (Ps = MUTE):
    {
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'SC','2,"MUTE"') (* Must have " " around string *)
    }
  }
}

DEFINE_CALL 'Page Control' (Pg,Ps)
{
  SELECT
  {
    ACTIVE (SR3cmd[2] = 0):  (* No change *)
    {
    }
    ACTIVE (SR3cmd[2] = SR3_LEFT):
    {
      Ps = (Ps-1) % 4  (* Step backwards thru 4 sources *)
      IF (!Ps)
        Ps = 4
      IF (Ps <> NewPs)
      {
        NewPs = Ps
        CALL 'Display Source' (Ps,Pg)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','2') (*  *)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','3') (*  *)
        SelectTimer = 40 (* Start timer 4 seconds *)
      }
    }
    ACTIVE (SR3cmd[2] = SR3_RIGHT):
    {
      Ps = (Ps+1) % 4  (* Step forwards thru 4 sources *)
      IF (!Ps)
        Ps = 4
      IF (Ps <> NewPs)
      {
        NewPs = Ps
        CALL 'Display Source' (Ps,Pg)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','2') (*  *)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','3') (*  *)
        SelectTimer = 40 (* Start timer 4 seconds *)
      }
    }
    ACTIVE (SR3cmd[2] = SR3_ENTER):
    {
      IF (PageSource[Pg] <> NewPs)
      {
        PageSource[Pg] = NewPs
        CALL 'EnterDevice'
      }
      SelectTimer = 0
      OldLevel = SR3level[2]
      SR3mutes[2] = 1 (* used to disable level update from SR 3 *)
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','2') (*  *)
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','3') (*  *)
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'IF',"ITOA(SR3level[2]+1),',0'")
      SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','1') (* Led on *)
      CANCEL_WAIT 'Pctrl'
      WAIT 5
        SR3mutes[2] = 0
    }
  }
  SR3cmd[2] = 0
}
(*********** System Start ****************)
(* Initializes system by clearing or setting all startup parameters,
   recalling memory 1 port and mic settings for ECS, memory 1 for the RPD 1, *)
DEFINE_CALL 'SystemStart'
{
  (* String Var RaneInfo[] for debug info *)
  RaneInfo = ""
  SR3active = 2 (* Only SR3 set to address 1 is used *)
  (* Bitwise - SR3 set to address 0 = Bit 0, SR3 set to address 1 = Bit 1, SR3 set to address 2 = Bit 2, *)
  (* SR3 set to address 3 = Bit 3, SR3 set to address 4 = Bit 4, SR3 set to address 5 = Bit 5... *)
  (* SR3active = 3  SR3 address 0 and 1 are used *)

  (* Set all startup Vols and pages *)
  (* SR3level is an array of all the levels [1] = SR3 address 0 *)
  SR3level[2] = 15  (* Set SR3#1 to mid level  *)
  SR3page[2]  = MUTE_PAGE   (* Set SR3#1 to page 1 - MUTE *)
  BarVol      = 15  (* Start with level set to mid position *)
  LobbyVol    = 15
  PoolVol     = 15
  Group = 1
  UpdateSR3[2] = 1
  OldLevel  = 0
  SelectTimer = 0
  PageSource = "MUTE,MUTE,MUTE,MUTE"
  NewPs = MUTE
  LedOff = 1

  WAIT 10
  {
    SystemOn    = 1
    SystemReady = 1
    SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','0') (* Led off *)
    SYSTEM_CALL 'RW485_Q' (1,SR_3,'FNT','1')
    (* The following mutes all inputs, sets the Master Out Vols,
       and sets Out 1&2 to Group 1 (Bar), sets Out 3&4 to Group 2 (Lobby),
       sets Out 5&6 to Group 3 (Pool) *)
    (* Only Send a maximum of 64 bytes *)
                          (* Command, Start Index, Data *)
                          (* IN1,IN2,IN3,IN4,IN5,IN6,Master,Limiter *)
    SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,0,"32,32,32,32,32,32,OUT_MASTER,28,
                              (*Out 2*)    32,32,32,32,32,32,OUT_MASTER,28,
                              (*Out 3*)    32,32,32,32,32,32,OUT_MASTER,28,
                              (*Out 4*)    32,32,32,32,32,32,OUT_MASTER,28,
                              (*Out 5*)    32,32,32,32,32,32,OUT_MASTER,28,
                              (*Out 6*)    32,32,32,32,32,32,OUT_MASTER,28,
                              (*Out Group*) 1,1,2,2,3,3")
                              (* set all group levels to 15 *)
    SYSTEM_CALL 'SRM_Q' (SRM_SEND_GROUP_LEVELS, 0, "15,15,15,15,15,15")
  }
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

  CREATE_BUFFER SR3, RW485rxBuffer
  CREATE_BUFFER SRM, SRMrxBuffer

  (* Remove comments if using an Axcent 3 *)
  SEND_COMMAND SRM, 'SET BAUD 9600,N,8,1,485 ENABLE'
(*
SEND_COMMAND SR3, 'SET BAUD 38400,N,8,1,485 DISABLE'  (* Use with DSC 1 or 2 *)
*)
  SEND_COMMAND SR3, 'SET BAUD 38400,N,8,1,485 ENABLE'  (* Direct connect *)
  SEND_COMMAND SR3, 'HSOFF'

  SYSTEM_CALL 'RaneIni'
  CALL 'SystemStart'

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

IF (SystemReady)
{
(* When New page is selected, display level and source *)
(* NewSR3page[2] is set in DoSR3 when a new page is selected by SR3 address 1  *)
  IF (NewSR3page[2])
  {
    CANCEL_WAIT 'Pctrl'
    SelectTimer = 0
    NewSR3page[2] = 0
    SELECT
    {
      ACTIVE (SR3page[2] = MUTE_PAGE): (* Page 1 Selected *)
      {
        SYSTEM_CALL 'SRM_Q' (SRM_SEND_PARAM,0,"32,32,32,32,32,32,OUT_MASTER,28,
                                  (*Out 2*)    32,32,32,32,32,32,OUT_MASTER,28,
                                  (*Out 3*)    32,32,32,32,32,32,OUT_MASTER,28,
                                  (*Out 4*)    32,32,32,32,32,32,OUT_MASTER,28,
                                  (*Out 5*)    32,32,32,32,32,32,OUT_MASTER,28,
                                  (*Out 6*)    32,32,32,32,32,32,OUT_MASTER,28,
                                  (*Out Group*) 1,1,2,2,3,3")
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','0') (* Led off *)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILK','1') (* Lock Encoder *)
        PageSource = "MUTE,MUTE,MUTE,MUTE"
        NewPs = MUTE
        SR3lock[2] = 1
        LedOff = 1
      }
      ACTIVE (SR3page[2] = BAR_PAGE): (* Page 1 Selected *)
      {
        CALL 'Display Source' (PageSource[BAR_PAGE],BAR_PAGE)
        SR3level[2] = BarVol
        Group = 1
        IF (SR3lock[2])
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILK','0') (* UnLock Encoder *)
        IF (LedOff)
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','1') (* Led on *)
      }
      ACTIVE (SR3page[2] = LOBBY_PAGE): (* Page 2 Selected *)
      {
        CALL 'Display Source' (PageSource[LOBBY_PAGE],LOBBY_PAGE)
        SR3level[2] = LobbyVol
        Group = 2
        IF (SR3lock[2])
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILK','0') (* UnLock Encoder *)
        IF (LedOff)
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','1') (* Led on *)
      }
      ACTIVE (SR3page[2] = POOL_PAGE): (* Page 3 Selected *)
      {
        CALL 'Display Source' (PageSource[POOL_PAGE],POOL_PAGE)
        SR3level[2] = PoolVol
        Group = 3
        IF (SR3lock[2])
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILK','0') (* UnLock Encoder *)
        IF (LedOff)
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','1') (* Led on *)
      }
    }
  } (* End NewSR3page *)


  IF (SelectTimer)  (* Allow for source select *)
  {
    SELECT
    {
      ACTIVE (SR3page[2] = BAR_PAGE): (* Page 2 Selected *)
      {
        WAIT 2 'Pctrl'
          CALL 'Page Control' (BAR_PAGE,NewPs)
      }
      ACTIVE (SR3page[2] = LOBBY_PAGE): (* Page 3 Selected *)
      {
        WAIT 2
          CALL 'Page Control' (LOBBY_PAGE,NewPs)
      }
      ACTIVE (SR3page[2] = POOL_PAGE): (* Page 4 Selected *)
      {
        WAIT 2
          CALL 'Page Control' (POOL_PAGE,NewPs)
      }
    }
  }  (* End SelectTimer *)
  (* Perform SRM group level when SR3 level changes *)
  ELSE
  {
    IF (SR3page[2] <> MUTE_PAGE)
    {
      IF (SR3cmd[2] = SR3_ENTER)  (* Press knob to enter source select mode *)
      {
        SR3cmd[2] = 0
        SR3mutes[2] = 1 (* Use to stop update from SR3level *)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','0') (* Led off *)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','2') (*  *)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','3') (*  *)
        SelectTimer = 40 (* Start timer 4 seconds *)
      }
      ELSE
      {
        IF (OldLevel <> SR3level[2])
        {
          OldLevel = SR3level[2]
          SRMlevel = 30 - SR3level[2]
          SYSTEM_CALL 'SRM_Q' (SRM_SEND_GROUP_LEVELS, Group - 1, "SRMlevel")
          SELECT
          {
            ACTIVE (Group = 1):
              BarVol = SR3level[2]
            ACTIVE (Group = 2):
              LobbyVol = SR3level[2]
            ACTIVE (Group = 3):
              PoolVol = SR3level[2]
          }
        }
      }
    }
  }
}   (* End SystemReady *)

IF (SystemOn)
{
  WAIT 1
  {
    IF (SelectTimer)
    {
      SelectTimer = SelectTimer - 1
      IF (!SelectTimer)
      {
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','2') (*  *)
        SYSTEM_CALL 'RW485_Q' (1,SR_3,'RVL','3') (*  *)
        CANCEL_WAIT 'Pctrl'
        WAIT 5
          SR3mutes[2] = 0
        IF (PageSource[SR3page[2]] <> NewPs)
        {
          PageSource[SR3page[2]] = NewPs
          CALL 'EnterDevice'
          OldLevel = SR3level[2]
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'IF',"ITOA(SR3level[2]+1),',0'")
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','1') (* Led on *)
        }
        ELSE
        {
          SYSTEM_CALL 'RW485_Q' (1,SR_3,'ILD','1') (* Led on *)
        }
      }
    }
  }
  SYSTEM_CALL 'DoRW485' (SR3) (* check RW485_Q and empty *)
(* DoSRM (Device SRM, Device SR1, Connection type) *)
(* SR1 Set 0 if not using the SR1 *)
(* Connection Type set to 1 if using Axcess without DSC, Set to 0 if using Netlinx or with DSC *)
  SYSTEM_CALL 'DoSRM' (SRM,0,1) (* No SR1 *)
  SYSTEM_CALL 'DoSR3'    (* Place below DoRW485 - check SR3 for its data *)
}

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

