PROGRAM_NAME='SRM_SLAVE - RANE SRM 66 SLAVE DEMO'
(*   DATE:10/11/01    TIME:14:55:02    *)
(* Rane Corp. By: Mike Slattery *)
(* This program demonstrates the SRM 66 in Slave mode.
   With the SRM 66 in Slave mode, both the SRM 66 and the SR 1s
   can operate from the same RS-485 port. In Slave mode only the
   Group Levels and Memory selection can be performed on the SRM 66.
   The SR 1 will perform the same. *)
(* Note: The control system performs the remote function and
         the remote sets the Group level. If the SR 1 is not
         connected the AMX sets the Group level. *)
(* Load the touch panel file SRMSLAVE.PGZ  *)
(* Include files: RaneCon.axi, RaneVar.axi *)
(* Library Files: RaneIni.lib, SR1_Q.lib, DoSR1.lib, Sr1SetLevel.lib *)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
TP          = 128
SR1         = 2  (* AXC-SER RANE SR1 9600,N,8,1,485 ENABLE*)

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

INCLUDE_SR1         = 1   (* This Program uses SR 1s  *)
  (* Must be after the Includes *)
INCLUDE 'RaneCon.axi'   (* RW232 Constants - Contains all the SPLs *)

(******** Button Names ***********)

VOL_BAR1    = 1
VOL_BAR2    = 2
VOL_BAR3    = 3
VOL_BAR4    = 4
VOL_BAR5    = 5
VOL_BAR6    = 6
VOL_BAR7    = 7

VOL1_MUTE_BTN = 1
VOL2_MUTE_BTN = 2
VOL3_MUTE_BTN = 3
VOL4_MUTE_BTN = 4
VOL5_MUTE_BTN = 5
VOL6_MUTE_BTN = 6
VOL7_MUTE_BTN = 7
VOL1_UP_BTN   = 10
VOL1_DWN_BTN  = 11
VOL2_UP_BTN   = 12
VOL2_DWN_BTN  = 13
VOL3_UP_BTN   = 14
VOL3_DWN_BTN  = 15
VOL4_UP_BTN   = 16
VOL4_DWN_BTN  = 17
VOL5_UP_BTN   = 18
VOL5_DWN_BTN  = 19
VOL6_UP_BTN   = 20
VOL6_DWN_BTN  = 21
VOL7_UP_BTN   = 22
VOL7_DWN_BTN  = 23

SYSTEM_ON   = 100
SYSTEM_OFF  = 101

MEM_SELECT1_BTN  = 41
MEM_SELECT2_BTN  = 42
MEM_SELECT3_BTN  = 43
MEM_SELECT4_BTN  = 44
MEM_SELECT5_BTN  = 45
MEM_SELECT6_BTN  = 46
MEM_SELECT7_BTN  = 47
MEM_SELECT8_BTN  = 48
MEM_SELECT9_BTN  = 49
MEM_SELECT10_BTN = 50
MEM_SELECT11_BTN = 51
MEM_SELECT12_BTN = 52
MEM_SELECT13_BTN = 53
MEM_SELECT14_BTN = 54
MEM_SELECT15_BTN = 55
MEM_SELECT16_BTN = 56
MEM_SELECT17_BTN = 57
MEM_SELECT18_BTN = 58
MEM_SELECT19_BTN = 59
MEM_SELECT20_BTN = 60
MEM_SELECT21_BTN = 61
MEM_SELECT22_BTN = 62
MEM_SELECT23_BTN = 63
MEM_SELECT24_BTN = 64
MEM_CLEAR = 53

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

INCLUDE 'RaneVar.axi'  (* RW232 Variables *)
SR1volume
Volume1
Volume2
Volume3
Volume4
Volume5
Volume6
Volume7
OldVolume1
OldVolume2
OldVolume3
OldVolume4
OldVolume5
OldVolume6
OldVolume7
OldCalVolume1
OldCalVolume2
OldCalVolume3
OldCalVolume4
OldCalVolume5
OldCalVolume6
OldCalVolume7
NewMem
SystemOn
TPmemory
NewVolume

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       TOGGLING DEFINITIONS GO BELOW                     *)
(***********************************************************)
DEFINE_TOGGLING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE
([TP,SYSTEM_ON],[TP,SYSTEM_OFF])
([TP,MEM_SELECT1_BTN]..[TP,MEM_SELECT24_BTN])

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)


(*********** Clear System ****************)
(* Initializes system by clearing or setting all startup parameters *)
DEFINE_CALL 'ClearSystem'
{
  RaneInfo = ""
  (* String Var RaneInfo[] for debug info *)
  SYSTEM_CALL 'RaneIni'
  SystemReady = 0
}

(*********** System Start ****************)
(* Initializes system by clearing or setting all startup parameters *)
DEFINE_CALL 'SystemStart'
{
  (* Power-up system *)
  (* ON[RELAY,POWER] *)

  OFF [TP,VOL1_MUTE_BTN]
  OFF [TP,VOL2_MUTE_BTN]
  OFF [TP,VOL3_MUTE_BTN]
  OFF [TP,VOL4_MUTE_BTN]
  OFF [TP,VOL5_MUTE_BTN]
  OFF [TP,VOL6_MUTE_BTN]
  OFF [TP,VOL7_MUTE_BTN]

  ON [TP,SYSTEM_ON]
  WAIT 10
  {
    CALL 'ClearSystem'
    SystemOn = 1
    SystemReady = 1
    (* select memory and load all group levels *)
    OldVolume1 = 255
    OldVolume2 = 255
    OldVolume3 = 255
    OldVolume4 = 255
    OldVolume5 = 255
    OldVolume6 = 255
    SR1volume = ((255-Volume1) * 30) / 255
    SYSTEM_CALL 'SR1_Q' (1,SR1_CMD_LEVEL,SR1volume)
    SR1volume = ((255-Volume2) * 30) / 255
    SYSTEM_CALL 'SR1_Q' (2,SR1_CMD_LEVEL,SR1volume)
    SR1volume = ((255-Volume3) * 30) / 255
    SYSTEM_CALL 'SR1_Q' (3,SR1_CMD_LEVEL,SR1volume)
    SR1volume = ((255-Volume4) * 30) / 255
    SYSTEM_CALL 'SR1_Q' (4,SR1_CMD_LEVEL,SR1volume)
    SR1volume = ((255-Volume5) * 30) / 255
    SYSTEM_CALL 'SR1_Q' (5,SR1_CMD_LEVEL,SR1volume)
    SR1volume = ((255-Volume6) * 30) / 255
    SYSTEM_CALL 'SR1_Q' (6,SR1_CMD_LEVEL,SR1volume)
    SR1volume = ((255-Volume7) * 30) / 255
    SYSTEM_CALL 'SR1_Q' (7,SR1_CMD_LEVEL,SR1volume)

    IF (TPmemory) (* Recall last known memory *)
    {
      ON [TP,TPmemory]
      SYSTEM_CALL 'SR1_Q' (0,SR1_CMD_MEMORY,TPmemory - MEM_SELECT1_BTN + 1)
    }
    ELSE (* Set to memory 1 at first start *)
    {
      ON [TP,MEM_SELECT1_BTN]
      SYSTEM_CALL 'SR1_Q' (0,SR1_CMD_MEMORY,1)
    }
  }
}

(*********** System Off ****************)
DEFINE_CALL 'SystemOff'
{
  (* Power-Down system *)
  (* OFF[RELAY,POWER] *)

(*  SEND_COMMAND TP,'PAGE-MAIN' *)
  SystemOn = 0
  ON [TP,SYSTEM_OFF]
  CALL 'ClearSystem'
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

  CREATE_BUFFER SR1, SR1rxBuffer
  (* Remove comments if using an Axcent 3 *)
  (* SEND_COMMAND SR1, 'SET BAUD 9600,N,8,1,485 ENABLE' *)

  SEND_COMMAND TP,'PAGE-MAIN'

  CREATE_LEVEL TP, VOL_BAR1, Volume1
  CREATE_LEVEL TP, VOL_BAR2, Volume2
  CREATE_LEVEL TP, VOL_BAR3, Volume3
  CREATE_LEVEL TP, VOL_BAR4, Volume4
  CREATE_LEVEL TP, VOL_BAR5, Volume5
  CREATE_LEVEL TP, VOL_BAR6, Volume6
  CREATE_LEVEL TP, VOL_BAR7, Volume7

  (* Set Bars to old level *)
  Volume1 = OldVolume1
  Volume2 = OldVolume2
  Volume3 = OldVolume3
  Volume4 = OldVolume4
  Volume5 = OldVolume5
  Volume6 = OldVolume6
  Volume7 = OldVolume7

  IF (Volume1)
  {
    SEND_LEVEL TP, VOL_BAR1, Volume1-1
    SEND_LEVEL TP, VOL_BAR1, Volume1
  }
  IF (Volume2)
  {
    SEND_LEVEL TP, VOL_BAR2, Volume2-1
    SEND_LEVEL TP, VOL_BAR2, Volume2
  }
  IF (Volume3)
  {
    SEND_LEVEL TP, VOL_BAR3, Volume3-1
    SEND_LEVEL TP, VOL_BAR3, Volume3
  }
  IF (Volume4)
  {
    SEND_LEVEL TP, VOL_BAR4, Volume4-1
    SEND_LEVEL TP, VOL_BAR4, Volume4
  }
  IF (Volume5)
  {
    SEND_LEVEL TP, VOL_BAR5, Volume5-1
    SEND_LEVEL TP, VOL_BAR5, Volume5
  }
  IF (Volume6)
  {
    SEND_LEVEL TP, VOL_BAR6, Volume6-1
    SEND_LEVEL TP, VOL_BAR6, Volume6
  }
  IF (Volume7)
  {
    SEND_LEVEL TP, VOL_BAR7, Volume7-1
    SEND_LEVEL TP, VOL_BAR7, Volume7
  }
  CALL 'SystemOff'

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(* System On *)
PUSH [TP,SYSTEM_ON]
  IF (!([TP,SYSTEM_ON]))
    CALL 'SystemStart'

(* System Off *)
PUSH [TP,SYSTEM_OFF]
  CALL 'SystemOff'

IF (SystemReady)
{
   (* When a new level is detected from the SR1, update the Vol Bar. *)
   (* SR1SetLevel is only required if SR1s are used *)
   (* SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR, Volume#, OldVolume#, SR1#) *)
   (* If Volume Bar is not used set TP and Bar to 0 *)
  SELECT
  {
    ACTIVE (NewSR1Level = 1): (* This parameter is set to the remote that has a new level. *)
      SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR1, Volume1, OldVolume1, 1)
    ACTIVE (NewSR1Level = 2):
      SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR2, Volume2, OldVolume2, 2)
    ACTIVE (NewSR1Level = 3):
      SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR3, Volume3, OldVolume3, 3)
    ACTIVE (NewSR1Level = 4):
      SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR4, Volume4, OldVolume4, 4)
    ACTIVE (NewSR1Level = 5):
      SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR5, Volume5, OldVolume5, 5)
    ACTIVE (NewSR1Level = 6):
      SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR6, Volume6, OldVolume6, 6)
    ACTIVE (NewSR1Level = 7):
      SYSTEM_CALL 'Sr1SetLevel'(TP, VOL_BAR7, Volume7, OldVolume7, 7)
  }

  (* Remote Level 1 *)
  NewVolume = 1  (* Set for remote number *)
                      (* TP,Up Btn,Dn Btn,MUTE,UNMUTE,Vol,OldlVol,OldCalVol,NewVol *)
  SYSTEM_CALL 'Sr1Vols'(TP, VOL1_UP_BTN, VOL1_DWN_BTN, VOL1_MUTE_BTN, 0, Volume1, OldVolume1, OldCalVolume1, NewVolume)
  IF (NewVolume)
  {
    NewVolume = 0
    StopSR1 = 60
    SEND_LEVEL TP,VOL_BAR1,Volume1
    SR1level[1] = OldCalVolume1
    OldSR1level[1] = OldCalVolume1
  }
  (* Remote Level 2 *)
  NewVolume = 2  (* Set for remote number *)
                      (* TP,Up Btn,Dn Btn,MUTE,UNMUTE,Vol,OldlVol,OldCalVol,NewVol *)
  SYSTEM_CALL 'Sr1Vols'(TP, VOL2_UP_BTN, VOL2_DWN_BTN, VOL2_MUTE_BTN, 0, Volume2, OldVolume2, OldCalVolume2, NewVolume)
  IF (NewVolume)
  {
    NewVolume = 0
    StopSR1 = 60
    SEND_LEVEL TP,VOL_BAR2,Volume2
    SR1level[2] = OldCalVolume2
    OldSR1level[2] = OldCalVolume2
  }
  (* Remote Level 3 *)
  NewVolume = 3  (* Set for remote number *)
                      (* TP,Up Btn,Dn Btn,MUTE,UNMUTE,Vol,OldlVol,OldCalVol,NewVol *)
  SYSTEM_CALL 'Sr1Vols'(TP, VOL3_UP_BTN, VOL3_DWN_BTN, VOL3_MUTE_BTN, 0, Volume3, OldVolume3, OldCalVolume3, NewVolume)
  IF (NewVolume)
  {
    NewVolume = 0
    StopSR1 = 60
    SEND_LEVEL TP,VOL_BAR3,Volume3
    SR1level[3] = OldCalVolume3
    OldSR1level[3] = OldCalVolume3
  }
  (* Remote Level 4 *)
  NewVolume = 4  (* Set for remote number *)
                      (* TP,Up Btn,Dn Btn,MUTE,UNMUTE,Vol,OldlVol,OldCalVol,NewVol *)
  SYSTEM_CALL 'Sr1Vols'(TP, VOL4_UP_BTN, VOL4_DWN_BTN, VOL4_MUTE_BTN, 0, Volume4, OldVolume4, OldCalVolume4, NewVolume)
  IF (NewVolume)
  {
    NewVolume = 0
    StopSR1 = 60
    SEND_LEVEL TP,VOL_BAR4,Volume4
    SR1level[4] = OldCalVolume4
    OldSR1level[4] = OldCalVolume4
  }
    (* Remote Level 5 *)
  NewVolume = 5  (* Set for remote number *)
                      (* TP,Up Btn,Dn Btn,MUTE,UNMUTE,Vol,OldlVol,OldCalVol,NewVol *)
  SYSTEM_CALL 'Sr1Vols'(TP, VOL5_UP_BTN, VOL5_DWN_BTN, VOL5_MUTE_BTN, 0, Volume5, OldVolume5, OldCalVolume5, NewVolume)
  IF (NewVolume)
  {
    NewVolume = 0
    StopSR1 = 60
    SEND_LEVEL TP,VOL_BAR5,Volume5
    SR1level[5] = OldCalVolume5
    OldSR1level[5] = OldCalVolume5
  }
  (* Remote Level 6 *)
  NewVolume = 6  (* Set for remote number *)
                      (* TP,Up Btn,Dn Btn,MUTE,UNMUTE,Vol,OldlVol,OldCalVol,NewVol *)
  SYSTEM_CALL 'Sr1Vols'(TP, VOL6_UP_BTN, VOL6_DWN_BTN, VOL6_MUTE_BTN, 0, Volume6, OldVolume6, OldCalVolume6, NewVolume)
  IF (NewVolume)
  {
    NewVolume = 0
    StopSR1 = 60
    SEND_LEVEL TP,VOL_BAR6,Volume6
    SR1level[6] = OldCalVolume6
    OldSR1level[6] = OldCalVolume6
  }
  (* Master Level 7 *)
  NewVolume = 7  (* Set for remote number *)
                      (* TP,Up Btn,Dn Btn,MUTE,UNMUTE,Vol,OldlVol,OldCalVol,NewVol *)
  SYSTEM_CALL 'Sr1Vols'(TP, VOL7_UP_BTN, VOL7_DWN_BTN, VOL7_MUTE_BTN, 0, Volume7, OldVolume7, OldCalVolume7, NewVolume)
  IF (NewVolume)
  {
    NewVolume = 0
    StopSR1 = 60
    SEND_LEVEL TP,VOL_BAR7,Volume7
    SR1level[7] = OldCalVolume7
    OldSR1level[7] = OldCalVolume7
  }

 (* Memory Recall *)

  PUSH [TP,MEM_SELECT1_BTN]
  {
    ON [TP,MEM_SELECT1_BTN]
    NewMem = 1
  }
  PUSH [TP,MEM_SELECT2_BTN]
  {
    ON [TP,MEM_SELECT2_BTN]
    NewMem = 2
  }
  PUSH [TP,MEM_SELECT3_BTN]
  {
    ON [TP,MEM_SELECT3_BTN]
    NewMem = 3
  }
  PUSH [TP,MEM_SELECT4_BTN]
  {
    ON [TP,MEM_SELECT4_BTN]
    NewMem = 4
  }
  PUSH [TP,MEM_SELECT5_BTN]
  {
    ON [TP,MEM_SELECT5_BTN]
    NewMem = 5
  }
  PUSH [TP,MEM_SELECT6_BTN]
  {
    ON [TP,MEM_SELECT6_BTN]
    NewMem = 6
  }
  PUSH [TP,MEM_SELECT7_BTN]
  {
    ON [TP,MEM_SELECT7_BTN]
    NewMem = 7
  }
  PUSH [TP,MEM_SELECT8_BTN]
  {
    ON [TP,MEM_SELECT8_BTN]
    NewMem = 8
  }
  PUSH [TP,MEM_SELECT9_BTN]
  {
    ON [TP,MEM_SELECT9_BTN]
    NewMem = 9
  }
  PUSH [TP,MEM_SELECT10_BTN]
  {
    ON [TP,MEM_SELECT10_BTN]
    NewMem = 10
  }
  PUSH [TP,MEM_SELECT11_BTN]
  {
    ON [TP,MEM_SELECT11_BTN]
    NewMem = 11
  }
  PUSH [TP,MEM_SELECT12_BTN]
  {
    ON [TP,MEM_SELECT12_BTN]
    NewMem = 12
  }
  PUSH [TP,MEM_SELECT12_BTN]
  {
    ON [TP,MEM_SELECT12_BTN]
    NewMem = 12
  }
  PUSH [TP,MEM_SELECT13_BTN]
  {
    ON [TP,MEM_SELECT13_BTN]
    NewMem = 13
  }
  PUSH [TP,MEM_SELECT14_BTN]
  {
    ON [TP,MEM_SELECT14_BTN]
    NewMem = 14
  }
  PUSH [TP,MEM_SELECT15_BTN]
  {
    ON [TP,MEM_SELECT15_BTN]
    NewMem = 15
  }
  PUSH [TP,MEM_SELECT16_BTN]
  {
    ON [TP,MEM_SELECT16_BTN]
    NewMem = 16
  }
  PUSH [TP,MEM_SELECT17_BTN]
  {
    ON [TP,MEM_SELECT17_BTN]
    NewMem = 17
  }
  PUSH [TP,MEM_SELECT18_BTN]
  {
    ON [TP,MEM_SELECT18_BTN]
    NewMem = 18
  }
  PUSH [TP,MEM_SELECT19_BTN]
  {
    ON [TP,MEM_SELECT19_BTN]
    NewMem = 19
  }
  PUSH [TP,MEM_SELECT20_BTN]
  {
    ON [TP,MEM_SELECT20_BTN]
    NewMem = 20
  }
  PUSH [TP,MEM_SELECT21_BTN]
  {
    ON [TP,MEM_SELECT21_BTN]
    NewMem = 21
  }
  PUSH [TP,MEM_SELECT22_BTN]
  {
    ON [TP,MEM_SELECT22_BTN]
    NewMem = 22
  }
  PUSH [TP,MEM_SELECT23_BTN]
  {
    ON [TP,MEM_SELECT23_BTN]
    NewMem = 23
  }
  PUSH [TP,MEM_SELECT24_BTN]
  {
    ON [TP,MEM_SELECT24_BTN]
    NewMem = 24
  }

  IF (NewMem)
  {
    SYSTEM_CALL 'SR1_Q' (0,SR1_CMD_MEMORY,NewMem)
    TPmemory = NewMem + MEM_SELECT1_BTN - 1
    NewMem = 0
  }
} (* End system ready *)

(* StopOpstat = 1 *)
IF (SystemOn)
{
(* Device Device SR1, Set to 1 if using Axcess without DSC1, Set to 0 if using Netlinx *)
  SYSTEM_CALL 'DoSR1' (SR1,1) (* SR1 connected directly, no DSC1 or Netlinx *)
}

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)
